@@ -92,10 +92,10 @@ _get_priority_range (GESContainer * container, guint32 * min_priority,
   GESLayer *layer = GES_CLIP (container)->priv->layer;
 
   if (layer) {
-    *min_priority = layer->min_gnl_priority;
-    *max_priority = layer->max_gnl_priority;
+    *min_priority = layer->min_nle_priority;
+    *max_priority = layer->max_nle_priority;
   } else {
-    *min_priority = MIN_GNL_PRIO;
+    *min_priority = MIN_NLE_PRIO;
     *max_priority = G_MAXUINT32;
   }
 }
@@ -223,12 +223,17 @@ _set_priority (GESTimelineElement * element, guint32 priority)
   for (tmp = container->children; tmp; tmp = g_list_next (tmp)) {
     guint32 real_tck_prio;
     GESTimelineElement *child = (GESTimelineElement *) tmp->data;
-    gint off = _PRIORITY (child) - _PRIORITY (element) - MIN_GNL_PRIO;
+    gint off = _ges_container_get_priority_offset (container, child);
 
-    if (off >= LAYER_HEIGHT)
+
+    if (off >= LAYER_HEIGHT) {
+      GST_ERROR ("%s child %s as a priority offset %d >= LAYER_HEIGHT %d"
+          " ==> clamping it to 0", GES_TIMELINE_ELEMENT_NAME (element),
+          GES_TIMELINE_ELEMENT_NAME (child), off, LAYER_HEIGHT);
       off = 0;
+    }
 
-    real_tck_prio = min_prio + priority + off;
+    real_tck_prio = min_prio + priority - off;
 
     if (real_tck_prio > max_prio) {
       GST_WARNING ("%p priority of %i, is outside of the its containing "
@@ -296,6 +301,7 @@ _add_child (GESContainer * container, GESTimelineElement * element)
    */
   _get_priority_range (container, &min_prio, &max_prio);
   if (GES_IS_BASE_EFFECT (element)) {
+    GESChildrenControlMode mode = container->children_control_mode;
 
     GST_DEBUG_OBJECT (container, "Adding %ith effect: %" GST_PTR_FORMAT
         " Priority %i", priv->nb_effects + 1, element,
@@ -303,12 +309,15 @@ _add_child (GESContainer * container, GESTimelineElement * element)
         priv->nb_effects);
 
     tmp = g_list_nth (GES_CONTAINER_CHILDREN (container), priv->nb_effects);
-    for (; tmp; tmp = tmp->next)
+    container->children_control_mode = GES_CHILDREN_UPDATE_OFFSETS;
+    for (; tmp; tmp = tmp->next) {
       ges_timeline_element_set_priority (GES_TIMELINE_ELEMENT (tmp->data),
           GES_TIMELINE_ELEMENT_PRIORITY (tmp->data) + 1);
+    }
 
     _set_priority0 (element, min_prio +
         GES_TIMELINE_ELEMENT_PRIORITY (container) + priv->nb_effects);
+    container->children_control_mode = mode;
     priv->nb_effects++;
   } else {
     /* We add the track element on top of the effect list */
@@ -590,7 +599,7 @@ _edit (GESContainer * container, GList * layers,
   }
 
   for (tmp = GES_CONTAINER_CHILDREN (container); tmp; tmp = g_list_next (tmp)) {
-    if (GES_IS_SOURCE (tmp->data)) {
+    if (GES_IS_SOURCE (tmp->data) || GES_IS_TRANSITION (tmp->data)) {
       ret &= ges_track_element_edit (tmp->data, layers, mode, edge, position);
       break;
     }
@@ -616,6 +625,44 @@ _edit (GESContainer * container, GList * layers,
   return ret;
 }
 
+static gboolean
+_paste (GESTimelineElement * element, GESTimelineElement * ref,
+    GstClockTime paste_position)
+{
+  GList *tmp;
+  GESClip *self = GES_CLIP (element);
+  GESClip *refclip = GES_CLIP (ref);
+
+  ges_clip_set_moving_from_layer (self, TRUE);
+  ges_layer_add_clip (refclip->priv->layer, self);
+  ges_clip_set_moving_from_layer (self, FALSE);
+
+  ges_timeline_element_set_start (GES_TIMELINE_ELEMENT (self), paste_position);
+
+  for (tmp = GES_CONTAINER_CHILDREN (refclip); tmp; tmp = tmp->next) {
+    GESTrackElement *new_trackelement, *trackelement =
+        GES_TRACK_ELEMENT (tmp->data);
+
+    new_trackelement =
+        GES_TRACK_ELEMENT (ges_timeline_element_copy (GES_TIMELINE_ELEMENT
+            (trackelement), FALSE));
+    if (new_trackelement == NULL) {
+      GST_WARNING_OBJECT (trackelement, "Could not create a copy");
+      continue;
+    }
+
+    ges_container_add (GES_CONTAINER (self),
+        GES_TIMELINE_ELEMENT (new_trackelement));
+
+    ges_track_element_copy_properties (GES_TIMELINE_ELEMENT (trackelement),
+        GES_TIMELINE_ELEMENT (new_trackelement));
+
+    ges_track_element_copy_bindings (trackelement, new_trackelement,
+        GST_CLOCK_TIME_NONE);
+  }
+
+  return TRUE;
+}
 
 
 /****************************************************
@@ -706,7 +753,7 @@ ges_clip_class_init (GESClipClass * klass)
   element_class->set_inpoint = _set_inpoint;
   element_class->set_priority = _set_priority;
   element_class->set_max_duration = _set_max_duration;
-  /* TODO implement the deep_copy Virtual method */
+  element_class->paste = _paste;
 
   container_class->add_child = _add_child;
   container_class->remove_child = _remove_child;
@@ -854,7 +901,7 @@ ges_clip_set_layer (GESClip * clip, GESLayer * layer)
    * it is actually the result of a move between layer (as we know
    * that it will be added to another layer right after, and this
    * is what imports here.) */
-  if (layer && !clip->priv->is_moving)
+  if (!clip->priv->is_moving)
     g_object_notify_by_pspec (G_OBJECT (clip), properties[PROP_LAYER]);
 }
 
@@ -1236,7 +1283,7 @@ ges_clip_split (GESClip * clip, guint64 position)
     ges_track_element_copy_properties (GES_TIMELINE_ELEMENT (trackelement),
         GES_TIMELINE_ELEMENT (new_trackelement));
 
-    ges_track_element_split_bindings (trackelement, new_trackelement,
+    ges_track_element_copy_bindings (trackelement, new_trackelement,
         position - start + inpoint);
   }
 
