@@ -77,6 +77,10 @@ struct _GESContainerPrivate
    */
   GHashTable *mappings;
   guint nb_effects;
+
+  /* List of GESTimelineElement being in the "child-added" signal
+   * emission stage */
+  GList *adding_children;
 };
 
 enum
@@ -185,6 +189,129 @@ _set_duration (GESTimelineElement * element, GstClockTime duration)
   return TRUE;
 }
 
+static void
+_ges_container_add_child_properties (GESContainer * container,
+    GESTimelineElement * child)
+{
+  guint n_props, i;
+
+  GParamSpec **child_props =
+      ges_timeline_element_list_children_properties (child,
+      &n_props);
+
+  for (i = 0; i < n_props; i++) {
+    GObject *prop_child;
+
+    if (ges_timeline_element_lookup_child (child, child_props[i]->name,
+            &prop_child, NULL)) {
+      ges_timeline_element_add_child_property (GES_TIMELINE_ELEMENT (container),
+          child_props[i], prop_child);
+
+    }
+
+    g_param_spec_unref (child_props[i]);
+  }
+
+  g_free (child_props);
+}
+
+static void
+_ges_container_remove_child_properties (GESContainer * container,
+    GESTimelineElement * child)
+{
+  guint n_props, i;
+
+  GParamSpec **child_props =
+      ges_timeline_element_list_children_properties (child,
+      &n_props);
+
+  for (i = 0; i < n_props; i++) {
+    GObject *prop_child;
+
+    if (ges_timeline_element_lookup_child (child, child_props[i]->name,
+            &prop_child, NULL)) {
+      ges_timeline_element_remove_child_property (GES_TIMELINE_ELEMENT
+          (container), child_props[i]);
+
+    }
+
+    g_param_spec_unref (child_props[i]);
+  }
+
+  g_free (child_props);
+}
+
+static GParamSpec **
+_list_children_properties (GESTimelineElement * self, guint * n_properties)
+{
+  GList *tmp;
+
+  for (tmp = GES_CONTAINER_CHILDREN (self); tmp; tmp = tmp->next)
+    _ges_container_add_child_properties (GES_CONTAINER (self), tmp->data);
+
+  return
+      GES_TIMELINE_ELEMENT_CLASS
+      (ges_container_parent_class)->list_children_properties (self,
+      n_properties);
+}
+
+static gboolean
+_lookup_child (GESTimelineElement * self, const gchar * prop_name,
+    GObject ** child, GParamSpec ** pspec)
+{
+  GList *tmp;
+
+  for (tmp = GES_CONTAINER_CHILDREN (self); tmp; tmp = tmp->next)
+    _ges_container_add_child_properties (GES_CONTAINER (self), tmp->data);
+
+  return
+      GES_TIMELINE_ELEMENT_CLASS (ges_container_parent_class)->lookup_child
+      (self, prop_name, child, pspec);
+}
+
+static GESTrackType
+_get_track_types (GESTimelineElement * object)
+{
+  GESTrackType types = GES_TRACK_TYPE_UNKNOWN;
+  GList *tmp, *children = ges_container_get_children (GES_CONTAINER (object),
+      TRUE);
+
+  for (tmp = children; tmp; tmp = tmp->next) {
+    if (GES_IS_TRACK_ELEMENT (tmp->data)) {
+      types |= ges_timeline_element_get_track_types (tmp->data);
+    }
+  }
+
+  g_list_free_full (children, gst_object_unref);
+
+  return types ^ GES_TRACK_TYPE_UNKNOWN;
+}
+
+static gboolean
+_paste (GESTimelineElement * element, GESTimelineElement * ref,
+    GstClockTime paste_position)
+{
+  GList *tmp;
+  GESContainer *self = GES_CONTAINER (element);
+  GESContainer *refcontainer = GES_CONTAINER (ref);
+
+  for (tmp = GES_CONTAINER_CHILDREN (refcontainer); tmp; tmp = tmp->next) {
+    ChildMapping *map;
+    GESTimelineElement *child, *refchild = GES_TIMELINE_ELEMENT (tmp->data);
+
+    map = g_hash_table_lookup (refcontainer->priv->mappings, refchild);
+    child = ges_timeline_element_copy (GES_TIMELINE_ELEMENT (refchild), TRUE);
+
+    ges_timeline_element_paste (child, paste_position + map->start_offset);
+    ges_timeline_element_set_timeline (element,
+        GES_TIMELINE_ELEMENT_TIMELINE (ref));
+    ges_container_add (self, child);
+  }
+
+  return TRUE;
+}
+
+
 /******************************************
  *                                        *
  * GObject virtual methods implementation *
@@ -257,6 +384,9 @@ ges_container_class_init (GESContainerClass * klass)
    * @element: the #GESTimelineElement that was added.
    *
    * Will be emitted after a child was added to @container.
+   * Usually you should connect with #g_signal_connect_after
+   * as in the first emission stage, the signal emission might
+   * get stopped internally.
    */
   ges_container_signals[CHILD_ADDED_SIGNAL] =
       g_signal_new ("child-added", G_TYPE_FROM_CLASS (klass),
@@ -281,6 +411,10 @@ ges_container_class_init (GESContainerClass * klass)
   element_class->set_start = _set_start;
   element_class->set_duration = _set_duration;
   element_class->set_inpoint = _set_inpoint;
+  element_class->list_children_properties = _list_children_properties;
+  element_class->lookup_child = _lookup_child;
+  element_class->get_track_types = _get_track_types;
+  element_class->paste = _paste;
 
   /* No default implementations */
   klass->remove_child = NULL;
@@ -558,8 +692,12 @@ ges_container_add (GESContainer * container, GESTimelineElement * child)
     return FALSE;
   }
 
+  _ges_container_add_child_properties (container, child);
+
+  priv->adding_children = g_list_prepend (priv->adding_children, child);
   g_signal_emit (container, ges_container_signals[CHILD_ADDED_SIGNAL], 0,
       child);
+  priv->adding_children = g_list_remove (priv->adding_children, child);
 
   return TRUE;
 }
@@ -602,8 +740,15 @@ ges_container_remove (GESContainer * container, GESTimelineElement * child)
   /* Let it live removing from our mappings */
   g_hash_table_remove (priv->mappings, child);
 
-  g_signal_emit (container, ges_container_signals[CHILD_REMOVED_SIGNAL], 0,
-      child);
+  _ges_container_remove_child_properties (container, child);
+
+  if (!g_list_find (container->priv->adding_children, child)) {
+    g_signal_emit (container, ges_container_signals[CHILD_REMOVED_SIGNAL], 0,
+        child);
+  } else {
+    GST_INFO_OBJECT (container, "Not emitting 'child-removed' signal as child"
+        " removal happend during 'child-added' signal emission");
+  }
   gst_object_unref (child);
 
   return TRUE;
