@@ -34,11 +34,11 @@
 GST_DEBUG_CATEGORY_EXTERN (_ges_debug);
 #define GST_CAT_DEFAULT _ges_debug
 
-/*  The first 2 GNL priorities are used for:
+/*  The first 2 NLE priorities are used for:
  *    0- The Mixing element
  *    1- The Gaps
  */
-#define MIN_GNL_PRIO 2
+#define MIN_NLE_PRIO 2
 #define LAYER_HEIGHT 1000
 
 #define _START(obj) GES_TIMELINE_ELEMENT_START (obj)
@@ -52,6 +52,18 @@ GST_DEBUG_CATEGORY_EXTERN (_ges_debug);
 #define _set_duration0 ges_timeline_element_set_duration
 #define _set_priority0 ges_timeline_element_set_priority
 
+#define GES_TIMELINE_ELEMENT_FORMAT \
+    "s:%p" \
+    " start: %" GST_TIME_FORMAT \
+    " inpoint: %" GST_TIME_FORMAT \
+    " duration: %" GST_TIME_FORMAT
+
+#define GES_TIMELINE_ELEMENT_ARGS(element) \
+    GES_TIMELINE_ELEMENT_NAME(element), element, \
+    GST_TIME_ARGS(GES_TIMELINE_ELEMENT_START(element)), \
+    GST_TIME_ARGS(GES_TIMELINE_ELEMENT_INPOINT(element)), \
+    GST_TIME_ARGS(GES_TIMELINE_ELEMENT_DURATION(element))
+
 G_GNUC_INTERNAL gboolean
 timeline_ripple_object         (GESTimeline *timeline, GESTrackElement *obj,
                                     GList * layers, GESEdge edge,
@@ -100,6 +112,21 @@ gboolean
 timeline_remove_element       (GESTimeline *timeline,
                                GESTimelineElement *element);
 
+G_GNUC_INTERNAL
+void
+timeline_fill_gaps            (GESTimeline *timeline);
+
+G_GNUC_INTERNAL GList *
+timeline_get_groups           (GESTimeline * timeline);
+
+G_GNUC_INTERNAL
+void
+track_resort_and_fill_gaps    (GESTrack *track);
+
+G_GNUC_INTERNAL
+void
+track_disable_last_gap        (GESTrack *track, gboolean disabled);
+
 G_GNUC_INTERNAL void
 ges_asset_cache_init (void);
 
@@ -107,14 +134,11 @@ G_GNUC_INTERNAL void
 ges_asset_set_id (GESAsset *asset, const gchar *id);
 
 G_GNUC_INTERNAL void
-ges_asset_cache_put (GESAsset * asset, GSimpleAsyncResult *res);
+ges_asset_cache_put (GESAsset * asset, GTask *task);
 
 G_GNUC_INTERNAL gboolean
 ges_asset_cache_set_loaded(GType extractable_type, const gchar * id, GError *error);
 
-G_GNUC_INTERNAL GHashTable *
-ges_track_element_get_bindings_hashtable(GESTrackElement *element);
-
 GESAsset*
 ges_asset_cache_lookup(GType extractable_type, const gchar * id);
 
@@ -155,7 +179,7 @@ ges_formatter_set_project                        (GESFormatter *formatter,
 G_GNUC_INTERNAL GESProject *
 ges_formatter_get_project                        (GESFormatter *formatter);
 G_GNUC_INTERNAL  GESAsset *
-_find_formatter_asset_for_uri                    (const gchar *uri);
+_find_formatter_asset_for_id                     (const gchar *id);
 
 
 
@@ -175,7 +199,6 @@ G_GNUC_INTERNAL  gchar * ges_project_try_updating_id              (GESProject *s
 G_GNUC_INTERNAL  void ges_project_add_loading_asset               (GESProject *project,
                                                                    GType extractable_type,
                                                                    const gchar *id);
-
 /************************************************
  *                                              *
  *   GESBaseXmlFormatter internal methods       *
@@ -215,7 +238,7 @@ G_GNUC_INTERNAL void ges_base_xml_formatter_add_track           (GESBaseXmlForma
                                                                  GstStructure *properties,
                                                                  const gchar *metadatas,
                                                                  GError **error);
-void ges_base_xml_formatter_add_encoding_profile               (GESBaseXmlFormatter * self,
+G_GNUC_INTERNAL void ges_base_xml_formatter_add_encoding_profile(GESBaseXmlFormatter * self,
                                                                  const gchar *type,
                                                                  const gchar *parent,
                                                                  const gchar * name,
@@ -229,6 +252,7 @@ void ges_base_xml_formatter_add_encoding_profile               (GESBaseXmlFormat
                                                                  guint pass,
                                                                  gboolean variableframerate,
                                                                  GstStructure * properties,
+                                                                 gboolean enabled,
                                                                  GError ** error);
 G_GNUC_INTERNAL void ges_base_xml_formatter_add_track_element   (GESBaseXmlFormatter *self,
                                                                  GType effect_type,
@@ -240,6 +264,18 @@ G_GNUC_INTERNAL void ges_base_xml_formatter_add_track_element   (GESBaseXmlForma
                                                                  const gchar *metadatas,
                                                                  GError **error);
 
+G_GNUC_INTERNAL void ges_base_xml_formatter_add_source          (GESBaseXmlFormatter *self,
+                                                                 const gchar * track_id,
+                                                                 GstStructure *children_properties);
+
+G_GNUC_INTERNAL void ges_base_xml_formatter_add_group           (GESBaseXmlFormatter *self,
+                                                                 const gchar *name,
+                                                                 const gchar *properties);
+
+G_GNUC_INTERNAL void ges_base_xml_formatter_last_group_add_child(GESBaseXmlFormatter *self,
+                                                                 const gchar * id,
+                                                                 const gchar * name);
+
 G_GNUC_INTERNAL void ges_base_xml_formatter_add_control_binding (GESBaseXmlFormatter * self,
                                                                   const gchar * binding_type,
                                                                   const gchar * source_type,
@@ -248,7 +284,7 @@ G_GNUC_INTERNAL void ges_base_xml_formatter_add_control_binding (GESBaseXmlForma
                                                                   const gchar *track_id,
                                                                   GSList * timed_values);
 
-G_GNUC_INTERNAL void set_property_foreach                       (GQuark field_id,
+G_GNUC_INTERNAL gboolean set_property_foreach                   (GQuark field_id,
                                                                  const GValue * value,
                                                                  GObject * object);;
 
@@ -264,12 +300,19 @@ G_GNUC_INTERNAL gint element_end_compare                  (GESTimelineElement *
 G_GNUC_INTERNAL GstElementFactory *
 ges_get_compositor_factory                                (void);
 
-void
+G_GNUC_INTERNAL void
 ges_base_xml_formatter_set_timeline_properties(GESBaseXmlFormatter * self,
 					       GESTimeline *timeline,
 					       const gchar *properties,
 					       const gchar *metadatas);
 
+
+/****************************************************
+ *        GESCommandLineFormatter                   *
+ ****************************************************/
+G_GNUC_INTERNAL GOptionGroup *
+_ges_command_line_formatter_get_option_group (void);
+
 /****************************************************
  *              GESContainer                        *
  ****************************************************/
@@ -279,30 +322,31 @@ G_GNUC_INTERNAL void _ges_container_sort_children_by_end  (GESContainer *contain
 /****************************************************
  *                  GESClip                         *
  ****************************************************/
-void              ges_clip_set_layer              (GESClip *clip, GESLayer  *layer);
-gboolean          ges_clip_is_moving_from_layer   (GESClip *clip);
-guint32           ges_clip_get_layer_priority     (GESClip *clip);
-void              ges_clip_set_moving_from_layer  (GESClip *clip, gboolean is_moving);
-GESTrackElement*  ges_clip_create_track_element   (GESClip *clip, GESTrackType type);
-GList*            ges_clip_create_track_elements  (GESClip *clip, GESTrackType type);
+G_GNUC_INTERNAL void              ges_clip_set_layer              (GESClip *clip, GESLayer  *layer);
+G_GNUC_INTERNAL gboolean          ges_clip_is_moving_from_layer   (GESClip *clip);
+G_GNUC_INTERNAL guint32           ges_clip_get_layer_priority     (GESClip *clip);
+G_GNUC_INTERNAL void              ges_clip_set_moving_from_layer  (GESClip *clip, gboolean is_moving);
+G_GNUC_INTERNAL GESTrackElement*  ges_clip_create_track_element   (GESClip *clip, GESTrackType type);
+G_GNUC_INTERNAL GList*            ges_clip_create_track_elements  (GESClip *clip, GESTrackType type);
 
 
 /****************************************************
  *              GESTrackElement                     *
  ****************************************************/
-#define         GNL_OBJECT_TRACK_ELEMENT_QUARK                  (g_quark_from_string ("gnl_object_track_element_quark"))
+#define         NLE_OBJECT_TRACK_ELEMENT_QUARK                  (g_quark_from_string ("nle_object_track_element_quark"))
 G_GNUC_INTERNAL gboolean  ges_track_element_set_track           (GESTrackElement * object, GESTrack * track);
 G_GNUC_INTERNAL guint32   _ges_track_element_get_layer_priority (GESTrackElement * element);
 G_GNUC_INTERNAL void ges_track_element_copy_properties          (GESTimelineElement * element,
                                                                  GESTimelineElement * elementcopy);
 
-G_GNUC_INTERNAL void ges_track_element_split_bindings (GESTrackElement *element,
+G_GNUC_INTERNAL void ges_track_element_copy_bindings (GESTrackElement *element,
 						       GESTrackElement *new_element,
 						       guint64 position);
 
 G_GNUC_INTERNAL GstElement *ges_source_create_topbin (const gchar * bin_name, GstElement * sub_element, ...);
-
-G_GNUC_INTERNAL void ges_track_set_caps (GESTrack *track, const GstCaps *caps);
+G_GNUC_INTERNAL void ges_track_set_caps                (GESTrack *track,
+                                                        const GstCaps *caps);
+G_GNUC_INTERNAL GstElement * ges_track_get_composition (GESTrack *track);
 
 
 /*********************************************
@@ -327,4 +371,17 @@ typedef struct GESMultiFileURI
 
 G_GNUC_INTERNAL GESMultiFileURI * ges_multi_file_uri_new (const gchar * uri);
 
+/************************
+ * Our property masks   *
+ ************************/
+#define GES_PARAM_NO_SERIALIZATION (1 << (G_PARAM_USER_SHIFT + 1))
+
+/********************
+ *  Gnonlin helpers *
+ ********************/
+
+G_GNUC_INTERNAL gboolean ges_nle_composition_add_object (GstElement *comp, GstElement *object);
+G_GNUC_INTERNAL gboolean ges_nle_composition_remove_object (GstElement *comp, GstElement *object);
+G_GNUC_INTERNAL gboolean ges_nle_object_commit (GstElement * nlesource, gboolean recurse);
+
 #endif /* __GES_INTERNAL_H__ */
