@@ -161,6 +161,9 @@ ges_layer_class_init (GESLayerClass * klass)
    * priority. Conceptually, a #GESTimeline is a stack of GESLayers,
    * and the priority of the layer represents its position in the stack. Two
    * layers should not have the same priority within a given GESTimeline.
+   *
+   * Note that the timeline needs to be commited (with #ges_timeline_commit)
+   * for the change to be taken into account.
    */
   g_object_class_install_property (object_class, PROP_PRIORITY,
       g_param_spec_uint ("priority", "Priority",
@@ -209,8 +212,8 @@ ges_layer_init (GESLayer * self)
 
   self->priv->priority = 0;
   self->priv->auto_transition = FALSE;
-  self->min_gnl_priority = MIN_GNL_PRIO;
-  self->max_gnl_priority = LAYER_HEIGHT + MIN_GNL_PRIO;
+  self->min_nle_priority = MIN_NLE_PRIO;
+  self->max_nle_priority = LAYER_HEIGHT + MIN_NLE_PRIO;
 
   _register_metas (self);
 }
@@ -342,16 +345,17 @@ ges_layer_remove_clip (GESLayer * layer, GESClip * clip)
   }
   gst_object_unref (current_layer);
 
+  /* Remove it from our list of controlled objects */
+  layer->priv->clips_start = g_list_remove (layer->priv->clips_start, clip);
+
   /* emit 'clip-removed' */
   g_signal_emit (layer, ges_layer_signals[OBJECT_REMOVED], 0, clip);
 
   /* inform the clip it's no longer in a layer */
   ges_clip_set_layer (clip, NULL);
   /* so neither in a timeline */
-  ges_timeline_element_set_timeline (GES_TIMELINE_ELEMENT (clip), NULL);
-
-  /* Remove it from our list of controlled objects */
-  layer->priv->clips_start = g_list_remove (layer->priv->clips_start, clip);
+  if (layer->timeline)
+    ges_timeline_element_set_timeline (GES_TIMELINE_ELEMENT (clip), NULL);
 
   /* Remove our reference to the clip */
   gst_object_unref (clip);
@@ -376,8 +380,8 @@ ges_layer_set_priority (GESLayer * layer, guint priority)
 
   if (priority != layer->priv->priority) {
     layer->priv->priority = priority;
-    layer->min_gnl_priority = (priority * LAYER_HEIGHT) + MIN_GNL_PRIO;
-    layer->max_gnl_priority = ((priority + 1) * LAYER_HEIGHT) + MIN_GNL_PRIO;
+    layer->min_nle_priority = (priority * LAYER_HEIGHT) + MIN_NLE_PRIO;
+    layer->max_nle_priority = ((priority + 1) * LAYER_HEIGHT) + MIN_NLE_PRIO;
 
     ges_layer_resync_priorities (layer);
   }
@@ -686,7 +690,13 @@ ges_layer_get_timeline (GESLayer * layer)
 void
 ges_layer_set_timeline (GESLayer * layer, GESTimeline * timeline)
 {
+  GList *tmp;
+
   GST_DEBUG ("layer:%p, timeline:%p", layer, timeline);
 
+  for (tmp = layer->priv->clips_start; tmp; tmp = tmp->next) {
+    ges_timeline_element_set_timeline (tmp->data, timeline);
+  }
+
   layer->timeline = timeline;
 }
