@@ -37,6 +37,10 @@
 #include "ges-audio-track.h"
 #include "ges-video-track.h"
 
+GST_DEBUG_CATEGORY_STATIC (ges_pipeline_debug);
+#undef GST_CAT_DEFAULT
+#define GST_CAT_DEFAULT ges_pipeline_debug
+
 #define DEFAULT_TIMELINE_MODE  GES_PIPELINE_MODE_PREVIEW
 
 /* Structure corresponding to a timeline - sink link */
@@ -48,8 +52,8 @@ typedef struct
   GstPad *srcpad;               /* Timeline source pad */
   GstPad *playsinkpad;
   GstPad *encodebinpad;
-  GstPad *blocked_pad;
-  gulong probe_id;
+
+  guint query_position_id;
 } OutputChain;
 
 
@@ -65,6 +69,7 @@ struct _GESPipelinePrivate
 
   GMutex dyn_mutex;
   GList *chains;
+  GList *not_rendered_tracks;
 
   GstEncodingProfile *profile;
 };
@@ -76,6 +81,8 @@ enum
   PROP_VIDEO_SINK,
   PROP_TIMELINE,
   PROP_MODE,
+  PROP_AUDIO_FILTER,
+  PROP_VIDEO_FILTER,
   PROP_LAST
 };
 
@@ -88,6 +95,8 @@ static OutputChain *get_output_chain_for_track (GESPipeline * self,
     GESTrack * track);
 static OutputChain *new_output_chain_for_track (GESPipeline * self,
     GESTrack * track);
+static void _link_track (GESPipeline * self, GESTrack * track);
+static void _unlink_track (GESPipeline * self, GESTrack * track);
 
 /****************************************************
  *    Video Overlay vmethods implementation         *
@@ -115,8 +124,8 @@ _overlay_set_render_rectangle (GstVideoOverlay * overlay, gint x,
 {
   GESPipeline *pipeline = GES_PIPELINE (overlay);
 
-  gst_video_overlay_set_render_rectangle (GST_VIDEO_OVERLAY (pipeline->
-          priv->playsink), x, y, width, height);
+  gst_video_overlay_set_render_rectangle (GST_VIDEO_OVERLAY (pipeline->priv->
+          playsink), x, y, width, height);
 }
 
 static void
@@ -124,8 +133,8 @@ _overlay_set_window_handle (GstVideoOverlay * overlay, guintptr handle)
 {
   GESPipeline *pipeline = GES_PIPELINE (overlay);
 
-  gst_video_overlay_set_window_handle (GST_VIDEO_OVERLAY (pipeline->priv->
-          playsink), handle);
+  gst_video_overlay_set_window_handle (GST_VIDEO_OVERLAY (pipeline->
+          priv->playsink), handle);
 }
 
 static void
@@ -164,6 +173,14 @@ ges_pipeline_get_property (GObject * object, guint property_id,
     case PROP_MODE:
       g_value_set_flags (value, self->priv->mode);
       break;
+    case PROP_AUDIO_FILTER:
+      g_object_get_property (G_OBJECT (self->priv->playsink), "audio-filter",
+          value);
+      break;
+    case PROP_VIDEO_FILTER:
+      g_object_get_property (G_OBJECT (self->priv->playsink), "video-filter",
+          value);
+      break;
     default:
       G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
   }
@@ -191,11 +208,36 @@ ges_pipeline_set_property (GObject * object, guint property_id,
     case PROP_MODE:
       ges_pipeline_set_mode (GES_PIPELINE (object), g_value_get_flags (value));
       break;
+    case PROP_AUDIO_FILTER:
+      g_object_set (self->priv->playsink, "audio-filter",
+          GST_ELEMENT (g_value_get_object (value)), NULL);
+      break;
+    case PROP_VIDEO_FILTER:
+      g_object_set (self->priv->playsink, "video-filter",
+          GST_ELEMENT (g_value_get_object (value)), NULL);
+      break;
     default:
       G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
   }
 }
 
+static void
+_timeline_track_added_cb (GESTimeline * timeline, GESTrack * track,
+    GESPipeline * pipeline)
+{
+  track_disable_last_gap (track,
+      ! !(pipeline->priv->mode & (GES_PIPELINE_MODE_RENDER |
+              GES_PIPELINE_MODE_SMART_RENDER)));
+  _link_track (pipeline, track);
+}
+
+static void
+_timeline_track_removed_cb (GESTimeline * timeline, GESTrack * track,
+    GESPipeline * pipeline)
+{
+  _unlink_track (pipeline, track);
+}
+
 static void
 ges_pipeline_dispose (GObject * object)
 {
@@ -223,6 +265,13 @@ ges_pipeline_dispose (GObject * object)
     self->priv->profile = NULL;
   }
 
+  if (self->priv->timeline) {
+    g_signal_handlers_disconnect_by_func (self->priv->timeline,
+        _timeline_track_added_cb, self);
+    g_signal_handlers_disconnect_by_func (self->priv->timeline,
+        _timeline_track_removed_cb, self);
+  }
+
   G_OBJECT_CLASS (ges_pipeline_parent_class)->dispose (object);
 }
 
@@ -234,6 +283,9 @@ ges_pipeline_class_init (GESPipelineClass * klass)
 
   g_type_class_add_private (klass, sizeof (GESPipelinePrivate));
 
+  GST_DEBUG_CATEGORY_INIT (ges_pipeline_debug, "gespipeline",
+      GST_DEBUG_FG_YELLOW, "ges pipeline");
+
   object_class->dispose = ges_pipeline_dispose;
   object_class->get_property = ges_pipeline_get_property;
   object_class->set_property = ges_pipeline_set_property;
@@ -246,8 +298,6 @@ ges_pipeline_class_init (GESPipelineClass * klass)
   properties[PROP_AUDIO_SINK] = g_param_spec_object ("audio-sink", "Audio Sink",
       "Audio sink for the preview.",
       GST_TYPE_ELEMENT, G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS);
-  g_object_class_install_property (object_class, PROP_AUDIO_SINK,
-      properties[PROP_AUDIO_SINK]);
 
   /**
    * GESPipeline:video-sink:
@@ -257,8 +307,6 @@ ges_pipeline_class_init (GESPipelineClass * klass)
   properties[PROP_VIDEO_SINK] = g_param_spec_object ("video-sink", "Video Sink",
       "Video sink for the preview.",
       GST_TYPE_ELEMENT, G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS);
-  g_object_class_install_property (object_class, PROP_VIDEO_SINK,
-      properties[PROP_VIDEO_SINK]);
 
   /**
    * GESPipeline:timeline:
@@ -270,8 +318,6 @@ ges_pipeline_class_init (GESPipelineClass * klass)
       "Timeline to use in this pipeline. See also "
       "ges_pipeline_set_timeline() for more info.",
       GES_TYPE_TIMELINE, G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS);
-  g_object_class_install_property (object_class, PROP_TIMELINE,
-      properties[PROP_TIMELINE]);
 
   /**
    * GESPipeline:mode:
@@ -283,8 +329,32 @@ ges_pipeline_class_init (GESPipelineClass * klass)
       "Pipeline mode. See ges_pipeline_set_mode() for more info.",
       GES_TYPE_PIPELINE_FLAGS, DEFAULT_TIMELINE_MODE,
       G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS);
-  g_object_class_install_property (object_class, PROP_MODE,
-      properties[PROP_MODE]);
+
+  /**
+   * GESPipeline::audio-filter
+   *
+   * The audio filter(s) to apply during playback right before the audio sink
+   *
+   * Since: 1.6.0
+   */
+  properties[PROP_AUDIO_FILTER] =
+      g_param_spec_object ("audio-filter", "Audio filter",
+      "the audio filter(s) to apply, if possible", GST_TYPE_ELEMENT,
+      G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS);
+
+  /**
+   * GESPipeline::video-filter
+   *
+   * The video filter(s) to apply during playback right before the video sink
+   *
+   * Since: 1.6.0
+   */
+  properties[PROP_VIDEO_FILTER] =
+      g_param_spec_object ("video-filter", "Video filter",
+      "the Video filter(s) to apply, if possible", GST_TYPE_ELEMENT,
+      G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS);
+
+  g_object_class_install_properties (object_class, PROP_LAST, properties);
 
   element_class->change_state = GST_DEBUG_FUNCPTR (ges_pipeline_change_state);
 
@@ -434,6 +504,39 @@ done:
   return TRUE;
 }
 
+static void
+_link_tracks (GESPipeline * pipeline)
+{
+  GList *tmp;
+
+  GST_DEBUG_OBJECT (pipeline, "Linking tracks");
+
+  if (!pipeline->priv->timeline) {
+    GST_INFO_OBJECT (pipeline, "Not timeline set yet, doing nothing");
+
+    return;
+  }
+
+  for (tmp = pipeline->priv->timeline->tracks; tmp; tmp = tmp->next)
+    _link_track (pipeline, tmp->data);
+}
+
+static void
+_unlink_tracks (GESPipeline * pipeline)
+{
+  GList *tmp;
+
+  GST_DEBUG_OBJECT (pipeline, "Disconnecting all tracks");
+  if (!pipeline->priv->timeline) {
+    GST_INFO_OBJECT (pipeline, "Not timeline set yet, doing nothing");
+
+    return;
+  }
+
+  for (tmp = pipeline->priv->timeline->tracks; tmp; tmp = tmp->next)
+    _unlink_track (pipeline, tmp->data);
+}
+
 static GstStateChangeReturn
 ges_pipeline_change_state (GstElement * element, GstStateChange transition)
 {
@@ -453,12 +556,21 @@ ges_pipeline_change_state (GstElement * element, GstStateChange transition)
       if (self->priv->mode & (GES_PIPELINE_MODE_RENDER |
               GES_PIPELINE_MODE_SMART_RENDER))
         GST_DEBUG ("rendering => Updating pipeline caps");
+      /* Set caps on all tracks according to profile if present */
       if (!ges_pipeline_update_caps (self)) {
         GST_ERROR_OBJECT (element, "Error setting the caps for rendering");
         ret = GST_STATE_CHANGE_FAILURE;
         goto done;
       }
-      /* Set caps on all tracks according to profile if present */
+      _link_tracks (self);
+      break;
+    case GST_STATE_CHANGE_PAUSED_TO_READY:
+    {
+      GList *tmp;
+
+      for (tmp = self->priv->not_rendered_tracks; tmp; tmp = tmp->next)
+        gst_element_set_locked_state (tmp->data, FALSE);
+    }
       break;
     default:
       break;
@@ -468,6 +580,14 @@ ges_pipeline_change_state (GstElement * element, GstStateChange transition)
       GST_ELEMENT_CLASS (ges_pipeline_parent_class)->change_state
       (element, transition);
 
+  switch (transition) {
+    case GST_STATE_CHANGE_PAUSED_TO_READY:
+      _unlink_tracks (self);
+      break;
+    default:
+      break;
+  }
+
 done:
   return ret;
 }
@@ -500,25 +620,21 @@ get_output_chain_for_track (GESPipeline * self, GESTrack * track)
 /* Fetches a compatible pad on the target element which isn't already
  * linked */
 static GstPad *
-get_compatible_unlinked_pad (GstElement * element, GstPad * pad)
+get_compatible_unlinked_pad (GstElement * element, GESTrack * track)
 {
   GstPad *res = NULL;
   GstIterator *pads;
   gboolean done = FALSE;
-  GstCaps *srccaps;
+  const GstCaps *srccaps;
   GValue paditem = { 0, };
 
-  if (G_UNLIKELY (pad == NULL))
-    goto no_pad;
+  if (G_UNLIKELY (track == NULL))
+    goto no_track;
 
-  GST_DEBUG ("element : %s, pad %s:%s",
-      GST_ELEMENT_NAME (element), GST_DEBUG_PAD_NAME (pad));
+  GST_DEBUG_OBJECT (element, " track %" GST_PTR_FORMAT, track);
 
-  if (GST_PAD_DIRECTION (pad) == GST_PAD_SRC)
-    pads = gst_element_iterate_sink_pads (element);
-  else
-    pads = gst_element_iterate_src_pads (element);
-  srccaps = gst_pad_query_caps (pad, NULL);
+  pads = gst_element_iterate_sink_pads (element);
+  srccaps = ges_track_get_caps (track);
 
   GST_DEBUG ("srccaps %" GST_PTR_FORMAT, srccaps);
 
@@ -553,34 +669,39 @@ get_compatible_unlinked_pad (GstElement * element, GstPad * pad)
   }
   g_value_reset (&paditem);
   gst_iterator_free (pads);
-  gst_caps_unref (srccaps);
 
   return res;
 
-no_pad:
+no_track:
   {
-    GST_ERROR ("No pad to check against");
+    GST_ERROR ("No track to check against");
     return NULL;
   }
 }
 
-static GstPadProbeReturn
-pad_blocked (GstPad * pad, GstPadProbeInfo * info, gpointer user_data)
+static GstClockTime
+_query_position_cb (GstElement * composition, GESPipeline * self)
 {
-  /* no nothing */
-  GST_DEBUG_OBJECT (pad, "blocked callback, blocked");
-  return GST_PAD_PROBE_OK;
+  gint64 position;
+
+  if (gst_element_query_position (GST_ELEMENT (self), GST_FORMAT_TIME,
+          &position))
+    return position;
+
+  return GST_CLOCK_TIME_NONE;
 }
 
 static void
-pad_added_cb (GstElement * timeline, GstPad * pad, GESPipeline * self)
+_link_track (GESPipeline * self, GESTrack * track)
 {
+  GstPad *pad;
   OutputChain *chain;
-  GESTrack *track;
   GstPad *sinkpad;
   GstCaps *caps;
+  GstPadLinkReturn lret;
   gboolean reconfigured = FALSE;
 
+  pad = ges_timeline_get_pad_for_track (self->priv->timeline, track);
   caps = gst_pad_query_caps (pad, NULL);
 
   GST_DEBUG_OBJECT (self, "new pad %s:%s , caps:%" GST_PTR_FORMAT,
@@ -588,8 +709,6 @@ pad_added_cb (GstElement * timeline, GstPad * pad, GESPipeline * self)
 
   gst_caps_unref (caps);
 
-  track = ges_timeline_get_track_for_pad (self->priv->timeline, pad);
-
   if (G_UNLIKELY (!track)) {
     GST_WARNING_OBJECT (self, "Couldn't find coresponding track !");
     return;
@@ -612,7 +731,19 @@ pad_added_cb (GstElement * timeline, GstPad * pad, GESPipeline * self)
   /* Get an existing chain or create it */
   if (!(chain = get_output_chain_for_track (self, track)))
     chain = new_output_chain_for_track (self, track);
+
+  if (chain->tee) {
+    GST_INFO_OBJECT (self, "Chain is already built");
+
+    return;
+  }
+
+  chain->query_position_id =
+      g_signal_connect (ges_track_get_composition (track), "query-position",
+      G_CALLBACK (_query_position_cb), self);
+
   chain->srcpad = pad;
+  gst_object_unref (pad);
 
   /* Adding tee */
   chain->tee = gst_element_factory_make ("tee", NULL);
@@ -621,7 +752,12 @@ pad_added_cb (GstElement * timeline, GstPad * pad, GESPipeline * self)
 
   /* Linking pad to tee */
   sinkpad = gst_element_get_static_pad (chain->tee, "sink");
-  gst_pad_link_full (pad, sinkpad, GST_PAD_LINK_CHECK_NOTHING);
+  lret = gst_pad_link (pad, sinkpad);
+  if (lret != GST_PAD_LINK_OK) {
+    GST_ERROR_OBJECT (self, "Could not link the tee (%i)", lret);
+    goto error;
+  }
+
   gst_object_unref (sinkpad);
 
   /* Connect playsink */
@@ -658,14 +794,11 @@ pad_added_cb (GstElement * timeline, GstPad * pad, GESPipeline * self)
     tmppad = gst_element_get_request_pad (chain->tee, "src_%u");
     if (G_UNLIKELY (gst_pad_link_full (tmppad, sinkpad,
                 GST_PAD_LINK_CHECK_NOTHING) != GST_PAD_LINK_OK)) {
-      GST_ERROR_OBJECT (self, "Couldn't link track pad to playsink");
+      GST_ERROR_OBJECT (self, "Couldn't link track pad to encodebin");
       gst_object_unref (tmppad);
       goto error;
     }
-    chain->blocked_pad = tmppad;
-    GST_DEBUG_OBJECT (tmppad, "blocking pad");
-    chain->probe_id = gst_pad_add_probe (tmppad,
-        GST_PAD_PROBE_TYPE_BLOCK_DOWNSTREAM, pad_blocked, NULL, NULL);
+    gst_object_unref (tmppad);
 
     GST_DEBUG ("Reconfiguring playsink");
 
@@ -678,14 +811,15 @@ pad_added_cb (GstElement * timeline, GstPad * pad, GESPipeline * self)
   }
 
   /* Connect to encodebin */
-  if (self->priv->
-      mode & (GES_PIPELINE_MODE_RENDER | GES_PIPELINE_MODE_SMART_RENDER)) {
+  if (self->
+      priv->mode & (GES_PIPELINE_MODE_RENDER | GES_PIPELINE_MODE_SMART_RENDER))
+  {
     GstPad *tmppad;
     GST_DEBUG_OBJECT (self, "Connecting to encodebin");
 
     if (!chain->encodebinpad) {
       /* Check for unused static pads */
-      sinkpad = get_compatible_unlinked_pad (self->priv->encodebin, pad);
+      sinkpad = get_compatible_unlinked_pad (self->priv->encodebin, track);
 
       if (sinkpad == NULL) {
         GstCaps *caps = gst_pad_query_caps (pad, NULL);
@@ -696,7 +830,13 @@ pad_added_cb (GstElement * timeline, GstPad * pad, GESPipeline * self)
         gst_caps_unref (caps);
 
         if (G_UNLIKELY (sinkpad == NULL)) {
-          GST_ERROR_OBJECT (self, "Couldn't get a pad from encodebin !");
+          GST_INFO_OBJECT (self, "Couldn't get a pad from encodebin !");
+          gst_element_set_locked_state (GST_ELEMENT (track), TRUE);
+
+          self->priv->not_rendered_tracks =
+              g_list_append (self->priv->not_rendered_tracks, track);
+
+
           goto error;
         }
       }
@@ -704,10 +844,9 @@ pad_added_cb (GstElement * timeline, GstPad * pad, GESPipeline * self)
     }
 
     tmppad = gst_element_get_request_pad (chain->tee, "src_%u");
-    if (G_UNLIKELY (gst_pad_link_full (tmppad,
-                chain->encodebinpad,
+    if (G_UNLIKELY (gst_pad_link_full (tmppad, chain->encodebinpad,
                 GST_PAD_LINK_CHECK_NOTHING) != GST_PAD_LINK_OK)) {
-      GST_WARNING_OBJECT (self, "Couldn't link track pad to playsink");
+      GST_ERROR_OBJECT (self, "Couldn't link track pad to encodebin");
       goto error;
     }
     gst_object_unref (tmppad);
@@ -724,37 +863,31 @@ pad_added_cb (GstElement * timeline, GstPad * pad, GESPipeline * self)
 error:
   {
     if (chain->tee) {
+      gst_element_set_state (chain->tee, GST_STATE_NULL);
       gst_bin_remove (GST_BIN_CAST (self), chain->tee);
     }
     if (sinkpad)
       gst_object_unref (sinkpad);
+
     g_free (chain);
   }
 }
 
 static void
-pad_removed_cb (GstElement * timeline, GstPad * pad, GESPipeline * self)
+_unlink_track (GESPipeline * self, GESTrack * track)
 {
   OutputChain *chain;
-  GESTrack *track;
-  GstPad *peer;
 
-  GST_DEBUG_OBJECT (self, "pad removed %s:%s", GST_DEBUG_PAD_NAME (pad));
-
-  if (G_UNLIKELY (!(track =
-              ges_timeline_get_track_for_pad (self->priv->timeline, pad)))) {
-    GST_WARNING_OBJECT (self, "Couldn't find coresponding track !");
-    return;
-  }
+  GST_DEBUG_OBJECT (self, "Unlinking removed %" GST_PTR_FORMAT, track);
 
   if (G_UNLIKELY (!(chain = get_output_chain_for_track (self, track)))) {
-    GST_DEBUG_OBJECT (self, "Pad wasn't used");
+    GST_DEBUG_OBJECT (self, "Track wasn't used");
     return;
   }
 
   /* Unlink encodebin */
   if (chain->encodebinpad) {
-    peer = gst_pad_get_peer (chain->encodebinpad);
+    GstPad *peer = gst_pad_get_peer (chain->encodebinpad);
     gst_pad_unlink (peer, chain->encodebinpad);
     gst_object_unref (peer);
     gst_element_release_request_pad (self->priv->encodebin,
@@ -764,27 +897,20 @@ pad_removed_cb (GstElement * timeline, GstPad * pad, GESPipeline * self)
 
   /* Unlink playsink */
   if (chain->playsinkpad) {
-    peer = gst_pad_get_peer (chain->playsinkpad);
+    GstPad *peer = gst_pad_get_peer (chain->playsinkpad);
     gst_pad_unlink (peer, chain->playsinkpad);
     gst_object_unref (peer);
     gst_element_release_request_pad (self->priv->playsink, chain->playsinkpad);
     gst_object_unref (chain->playsinkpad);
   }
 
-  if (chain->blocked_pad) {
-    GST_DEBUG_OBJECT (chain->blocked_pad, "unblocking pad");
-    gst_pad_remove_probe (chain->blocked_pad, chain->probe_id);
-    gst_object_unref (chain->blocked_pad);
-    chain->blocked_pad = NULL;
-    chain->probe_id = 0;
-  }
-
-  /* Unlike/remove tee */
-  peer = gst_element_get_static_pad (chain->tee, "sink");
-  gst_pad_unlink (pad, peer);
-  gst_object_unref (peer);
   gst_element_set_state (chain->tee, GST_STATE_NULL);
   gst_bin_remove (GST_BIN (self), chain->tee);
+  if (chain->query_position_id) {
+    g_signal_handler_disconnect (ges_track_get_composition (track),
+        chain->query_position_id);
+    chain->query_position_id = 0;
+  }
 
   self->priv->chains = g_list_remove (self->priv->chains, chain);
   g_free (chain);
@@ -792,25 +918,6 @@ pad_removed_cb (GstElement * timeline, GstPad * pad, GESPipeline * self)
   GST_DEBUG ("done");
 }
 
-static void
-no_more_pads_cb (GstElement * timeline, GESPipeline * self)
-{
-  GList *tmp;
-
-  GST_DEBUG ("received no-more-pads");
-  for (tmp = self->priv->chains; tmp; tmp = g_list_next (tmp)) {
-    OutputChain *chain = (OutputChain *) tmp->data;
-
-    if (chain->blocked_pad) {
-      GST_DEBUG_OBJECT (chain->blocked_pad, "unblocking pad");
-      gst_pad_remove_probe (chain->blocked_pad, chain->probe_id);
-      gst_object_unref (chain->blocked_pad);
-      chain->blocked_pad = NULL;
-      chain->probe_id = 0;
-    }
-  }
-}
-
 /**
  * ges_pipeline_set_timeline:
  * @pipeline: a #GESPipeline
@@ -826,6 +933,7 @@ no_more_pads_cb (GstElement * timeline, GESPipeline * self)
 gboolean
 ges_pipeline_set_timeline (GESPipeline * pipeline, GESTimeline * timeline)
 {
+
   g_return_val_if_fail (GES_IS_PIPELINE (pipeline), FALSE);
   g_return_val_if_fail (GES_IS_TIMELINE (timeline), FALSE);
   g_return_val_if_fail (pipeline->priv->timeline == NULL, FALSE);
@@ -838,13 +946,10 @@ ges_pipeline_set_timeline (GESPipeline * pipeline, GESTimeline * timeline)
   }
   pipeline->priv->timeline = timeline;
 
-  /* Connect to pipeline */
-  g_signal_connect (timeline, "pad-added", (GCallback) pad_added_cb, pipeline);
-  g_signal_connect (timeline, "pad-removed", (GCallback) pad_removed_cb,
-      pipeline);
-  g_signal_connect (timeline, "no-more-pads", (GCallback) no_more_pads_cb,
-      pipeline);
-
+  g_signal_connect (timeline, "track-added",
+      G_CALLBACK (_timeline_track_added_cb), pipeline);
+  g_signal_connect (timeline, "track-removed",
+      G_CALLBACK (_timeline_track_removed_cb), pipeline);
   /* FIXME Check if we should rollback if we can't sync state */
   gst_element_sync_state_with_parent (GST_ELEMENT (timeline));
 
@@ -895,6 +1000,8 @@ ges_pipeline_set_render_settings (GESPipeline * pipeline,
                 GES_IS_VIDEO_TRACK (tmptrack->data))) {
           GST_DEBUG_OBJECT (pipeline, "Setting presence to 1!");
           gst_encoding_profile_set_presence (tmpprofiles->data, 1);
+          gst_encoding_profile_set_allow_dynamic_output (tmpprofiles->data,
+              FALSE);
         }
       }
     }
@@ -969,6 +1076,8 @@ ges_pipeline_get_mode (GESPipeline * pipeline)
 gboolean
 ges_pipeline_set_mode (GESPipeline * pipeline, GESPipelineFlags mode)
 {
+
+  GList *tmp;
   g_return_val_if_fail (GES_IS_PIPELINE (pipeline), FALSE);
 
   GST_DEBUG_OBJECT (pipeline, "current mode : %d, mode : %d",
@@ -985,6 +1094,15 @@ ges_pipeline_set_mode (GESPipeline * pipeline, GESPipelineFlags mode)
   /* Switch pipeline to NULL since we're changing the configuration */
   gst_element_set_state (GST_ELEMENT_CAST (pipeline), GST_STATE_NULL);
 
+
+  if (pipeline->priv->timeline) {
+    gboolean disabled =
+        ! !(mode & (GES_PIPELINE_MODE_RENDER | GES_PIPELINE_MODE_SMART_RENDER));
+
+    for (tmp = pipeline->priv->timeline->tracks; tmp; tmp = tmp->next)
+      track_disable_last_gap (GES_TRACK (tmp->data), disabled);
+  }
+
   /* remove no-longer needed components */
   if (pipeline->priv->mode & GES_PIPELINE_MODE_PREVIEW &&
       !(mode & GES_PIPELINE_MODE_PREVIEW)) {
@@ -1026,7 +1144,6 @@ ges_pipeline_set_mode (GESPipeline * pipeline, GESPipelineFlags mode)
       (mode & GES_PIPELINE_MODE_PREVIEW)) {
     /* Add playsink */
     GST_DEBUG ("Adding playsink");
-
     if (!gst_bin_add (GST_BIN_CAST (pipeline), pipeline->priv->playsink)) {
       GST_ERROR_OBJECT (pipeline, "Couldn't add playsink");
       return FALSE;
