@@ -67,10 +67,28 @@ destroy_pad (PadInfos * infos)
   g_slice_free (PadInfos, infos);
 }
 
+GstPad *
+ges_smart_mixer_get_mixer_pad (GESSmartMixer * self, GstPad ** mixerpad)
+{
+  PadInfos *info;
+  GstPad *sinkpad;
+
+  sinkpad = gst_element_get_request_pad (GST_ELEMENT (self), "sink_%u");
+
+  if (sinkpad == NULL)
+    return NULL;
+
+  info = g_hash_table_lookup (self->pads_infos, sinkpad);
+  *mixerpad = gst_object_ref (info->mixer_pad);
+
+  return sinkpad;
+}
+
 /* These metadata will get set by the upstream framepositionner element,
    added in the video sources' bin */
 static GstPadProbeReturn
-parse_metadata (GstPad * mixer_pad, GstPadProbeInfo * info, gpointer unused)
+parse_metadata (GstPad * mixer_pad, GstPadProbeInfo * info,
+    GESSmartMixer * self)
 {
   GstFramePositionnerMeta *meta;
 
@@ -83,8 +101,13 @@ parse_metadata (GstPad * mixer_pad, GstPadProbeInfo * info, gpointer unused)
     return GST_PAD_PROBE_OK;
   }
 
-  g_object_set (mixer_pad, "alpha", meta->alpha, "xpos", meta->posx, "ypos",
-      meta->posy, "zorder", meta->zorder, NULL);
+  if (!self->disable_zorder_alpha) {
+    g_object_set (mixer_pad, "alpha", meta->alpha,
+        "zorder", meta->zorder, NULL);
+  }
+
+  g_object_set (mixer_pad, "xpos", meta->posx, "ypos",
+      meta->posy, "width", meta->width, "height", meta->height, NULL);
 
   return GST_PAD_PROBE_OK;
 }
@@ -141,7 +164,7 @@ _request_new_pad (GstElement * element, GstPadTemplate * templ,
 
   infos->probe_id =
       gst_pad_add_probe (infos->mixer_pad, GST_PAD_PROBE_TYPE_BUFFER,
-      (GstPadProbeCallback) parse_metadata, NULL, NULL);
+      (GstPadProbeCallback) parse_metadata, self, NULL);
 
   LOCK (self);
   g_hash_table_insert (self->pads_infos, ghost, infos);
@@ -171,6 +194,19 @@ _release_pad (GstElement * element, GstPad * pad)
 /****************************************************
  *              GObject vmethods                    *
  ****************************************************/
+static void
+ges_smart_mixer_dispose (GObject * object)
+{
+  GESSmartMixer *self = GES_SMART_MIXER (object);
+
+  if (self->pads_infos != NULL) {
+    g_hash_table_unref (self->pads_infos);
+    self->pads_infos = NULL;
+  }
+
+  G_OBJECT_CLASS (ges_smart_mixer_parent_class)->dispose (object);
+}
+
 static void
 ges_smart_mixer_finalize (GObject * object)
 {
@@ -202,6 +238,7 @@ ges_smart_mixer_class_init (GESSmartMixerClass * klass)
   element_class->request_new_pad = GST_DEBUG_FUNCPTR (_request_new_pad);
   element_class->release_pad = GST_DEBUG_FUNCPTR (_release_pad);
 
+  object_class->dispose = ges_smart_mixer_dispose;
   object_class->finalize = ges_smart_mixer_finalize;
 }
 
@@ -230,7 +267,6 @@ GstElement *
 ges_smart_mixer_new (GESTrack * track)
 {
   GESSmartMixer *self = g_object_new (GES_TYPE_SMART_MIXER, NULL);
-  self->track = track;
 
   /* FIXME Make mixer smart and let it properly negotiate caps! */
   return GST_ELEMENT (self);
