@@ -25,8 +25,6 @@
  * Corresponds to one output format (i.e. audio OR video).
  *
  * Contains the compatible TrackElement(s).
- *
- * Wraps GNonLin's 'gnlcomposition' element.
  */
 
 #include "ges-internal.h"
@@ -39,11 +37,17 @@
 G_DEFINE_TYPE_WITH_CODE (GESTrack, ges_track, GST_TYPE_BIN,
     G_IMPLEMENT_INTERFACE (GES_TYPE_META_CONTAINER, NULL));
 
+static GstStaticPadTemplate ges_track_src_pad_template =
+GST_STATIC_PAD_TEMPLATE ("src",
+    GST_PAD_SRC,
+    GST_PAD_ALWAYS,
+    GST_STATIC_CAPS_ANY);
+
 /* Structure that represents gaps and keep knowledge
  * of the gaps filled in the track */
 typedef struct
 {
-  GstElement *gnlobj;
+  GstElement *nleobj;
 
   GstClockTime start;
   GstClockTime duration;
@@ -57,6 +61,7 @@ struct _GESTrackPrivate
   GSequence *trackelements_by_start;
   GHashTable *trackelements_iter;
   GList *gaps;
+  gboolean last_gap_disabled;
 
   guint64 duration;
 
@@ -87,6 +92,7 @@ enum
   ARG_LAST,
   TRACK_ELEMENT_ADDED,
   TRACK_ELEMENT_REMOVED,
+  COMMITED,
   LAST_SIGNAL
 };
 
@@ -94,9 +100,6 @@ static guint ges_track_signals[LAST_SIGNAL] = { 0 };
 
 static GParamSpec *properties[ARG_LAST];
 
-static void pad_added_cb (GstElement * element, GstPad * pad, GESTrack * track);
-static void
-pad_removed_cb (GstElement * element, GstPad * pad, GESTrack * track);
 static void composition_duration_cb (GstElement * composition, GParamSpec * arg
     G_GNUC_UNUSED, GESTrack * obj);
 
@@ -111,17 +114,17 @@ add_trackelement_to_list_foreach (GESTrackElement * trackelement, GList ** list)
 static Gap *
 gap_new (GESTrack * track, GstClockTime start, GstClockTime duration)
 {
-  GstElement *gnlsrc, *elem;
+  GstElement *nlesrc, *elem;
 
   Gap *new_gap;
 
-  gnlsrc = gst_element_factory_make ("gnlsource", NULL);
+  nlesrc = gst_element_factory_make ("nlesource", NULL);
   elem = track->priv->create_element_for_gaps (track);
-  if (G_UNLIKELY (gst_bin_add (GST_BIN (gnlsrc), elem) == FALSE)) {
+  if (G_UNLIKELY (gst_bin_add (GST_BIN (nlesrc), elem) == FALSE)) {
     GST_WARNING_OBJECT (track, "Could not create gap filler");
 
-    if (gnlsrc)
-      gst_object_unref (gnlsrc);
+    if (nlesrc)
+      gst_object_unref (nlesrc);
 
     if (elem)
       gst_object_unref (elem);
@@ -129,12 +132,12 @@ gap_new (GESTrack * track, GstClockTime start, GstClockTime duration)
     return NULL;
   }
 
-  if (G_UNLIKELY (gst_bin_add (GST_BIN (track->priv->composition),
-              gnlsrc) == FALSE)) {
+  if (G_UNLIKELY (ges_nle_composition_add_object (track->priv->composition,
+              nlesrc) == FALSE)) {
     GST_WARNING_OBJECT (track, "Could not add gap to the composition");
 
-    if (gnlsrc)
-      gst_object_unref (gnlsrc);
+    if (nlesrc)
+      gst_object_unref (nlesrc);
 
     if (elem)
       gst_object_unref (elem);
@@ -146,10 +149,10 @@ gap_new (GESTrack * track, GstClockTime start, GstClockTime duration)
   new_gap->start = start;
   new_gap->duration = duration;
   new_gap->track = track;
-  new_gap->gnlobj = gst_object_ref (gnlsrc);
+  new_gap->nleobj = nlesrc;
 
 
-  g_object_set (gnlsrc, "start", new_gap->start, "duration", new_gap->duration,
+  g_object_set (nlesrc, "start", new_gap->start, "duration", new_gap->duration,
       "priority", 1, NULL);
 
   GST_DEBUG_OBJECT (track,
@@ -168,9 +171,7 @@ free_gap (Gap * gap)
   GST_DEBUG_OBJECT (track, "Removed gap with start %" GST_TIME_FORMAT
       " duration %" GST_TIME_FORMAT, GST_TIME_ARGS (gap->start),
       GST_TIME_ARGS (gap->duration));
-  gst_bin_remove (GST_BIN (track->priv->composition), gap->gnlobj);
-  gst_element_set_state (gap->gnlobj, GST_STATE_NULL);
-  gst_object_unref (gap->gnlobj);
+  ges_nle_composition_remove_object (track->priv->composition, gap->nleobj);
 
   g_slice_free (Gap, gap);
 }
@@ -183,7 +184,7 @@ update_gaps (GESTrack * track)
   GSequenceIter *it;
 
   GESTrackElement *trackelement;
-  GstClockTime start, end, duration = 0, timeline_duration;
+  GstClockTime start, end, duration = 0, timeline_duration = 0;
 
   GESTrackPrivate *priv = track->priv;
 
@@ -201,7 +202,7 @@ update_gaps (GESTrack * track)
       g_sequence_iter_is_end (it) == FALSE; it = g_sequence_iter_next (it)) {
     trackelement = g_sequence_get (it);
 
-    if (!ges_track_element_is_active(trackelement))
+    if (!ges_track_element_is_active (trackelement))
       continue;
 
     start = _START (trackelement);
@@ -218,7 +219,7 @@ update_gaps (GESTrack * track)
     duration = MAX (duration, end);
   }
 
-  /* 4- Add a gap at the end of the timeline if needed */
+  /* 3- Add a gap at the end of the timeline if needed */
   if (priv->timeline) {
     g_object_get (priv->timeline, "duration", &timeline_duration, NULL);
 
@@ -233,12 +234,25 @@ update_gaps (GESTrack * track)
     }
   }
 
+  if (!track->priv->last_gap_disabled) {
+    GST_DEBUG_OBJECT (track, "Adding a one second gap at the end");
+    gap = gap_new (track, timeline_duration, 1);
+    priv->gaps = g_list_prepend (priv->gaps, gap);
+  }
+
   /* 4- Remove old gaps */
   g_list_free_full (gaps, (GDestroyNotify) free_gap);
 }
 
-static inline void
-resort_and_fill_gaps (GESTrack * track)
+void
+track_disable_last_gap (GESTrack * track, gboolean disabled)
+{
+  track->priv->last_gap_disabled = disabled;
+  update_gaps (track);
+}
+
+void
+track_resort_and_fill_gaps (GESTrack * track)
 {
   g_sequence_sort (track->priv->trackelements_by_start,
       (GCompareDataFunc) element_start_compare, NULL);
@@ -248,6 +262,13 @@ resort_and_fill_gaps (GESTrack * track)
   }
 }
 
+static gboolean
+update_field (GQuark field_id, const GValue * value, GstStructure * original)
+{
+  gst_structure_id_set_value (original, field_id, value);
+  return TRUE;
+}
+
 /* callbacks */
 static void
 sort_track_elements_cb (GESTrackElement * child,
@@ -258,11 +279,12 @@ sort_track_elements_cb (GESTrackElement * child,
 }
 
 static void
-pad_added_cb (GstElement * element, GstPad * pad, GESTrack * track)
+_ghost_nlecomposition_srcpad (GESTrack * track)
 {
-  GESTrackPrivate *priv = track->priv;
   GstPad *capsfilter_sink;
   GstPad *capsfilter_src;
+  GESTrackPrivate *priv = track->priv;
+  GstPad *pad = gst_element_get_static_pad (priv->composition, "src");
 
   capsfilter_sink = gst_element_get_static_pad (priv->capsfilter, "sink");
 
@@ -281,22 +303,6 @@ pad_added_cb (GstElement * element, GstPad * pad, GESTrack * track)
   GST_DEBUG ("done");
 }
 
-static void
-pad_removed_cb (GstElement * element, GstPad * pad, GESTrack * track)
-{
-  GESTrackPrivate *priv = track->priv;
-
-  GST_DEBUG ("track:%p, pad %s:%s", track, GST_DEBUG_PAD_NAME (pad));
-
-  if (G_LIKELY (priv->srcpad)) {
-    gst_pad_set_active (priv->srcpad, FALSE);
-    gst_element_remove_pad (GST_ELEMENT (track), priv->srcpad);
-    priv->srcpad = NULL;
-  }
-
-  GST_DEBUG ("done");
-}
-
 static void
 composition_duration_cb (GstElement * composition,
     GParamSpec * arg G_GNUC_UNUSED, GESTrack * track)
@@ -317,6 +323,20 @@ composition_duration_cb (GstElement * composition,
   }
 }
 
+static void
+composition_commited_cb (GstElement * composition, gboolean changed,
+    GESTrack * self)
+{
+  g_signal_emit (self, ges_track_signals[COMMITED], 0);
+}
+
+/* Internal */
+GstElement *
+ges_track_get_composition (GESTrack * track)
+{
+  return track->priv->composition;
+}
+
 /* FIXME: Find out how to avoid doing this "hack" using the GDestroyNotify
  * function pointer in the trackelements_by_start GSequence
  *
@@ -328,7 +348,7 @@ static gboolean
 remove_object_internal (GESTrack * track, GESTrackElement * object)
 {
   GESTrackPrivate *priv;
-  GstElement *gnlobject;
+  GstElement *nleobject;
 
   GST_DEBUG_OBJECT (track, "object:%p", object);
 
@@ -339,16 +359,14 @@ remove_object_internal (GESTrack * track, GESTrackElement * object)
     return FALSE;
   }
 
-  if ((gnlobject = ges_track_element_get_gnlobject (object))) {
-    GST_DEBUG ("Removing GnlObject '%s' from composition '%s'",
-        GST_ELEMENT_NAME (gnlobject), GST_ELEMENT_NAME (priv->composition));
+  if ((nleobject = ges_track_element_get_nleobject (object))) {
+    GST_DEBUG ("Removing NleObject '%s' from composition '%s'",
+        GST_ELEMENT_NAME (nleobject), GST_ELEMENT_NAME (priv->composition));
 
-    if (!gst_bin_remove (GST_BIN (priv->composition), gnlobject)) {
-      GST_WARNING ("Failed to remove gnlobject from composition");
+    if (!ges_nle_composition_remove_object (priv->composition, nleobject)) {
+      GST_WARNING ("Failed to remove nleobject from composition");
       return FALSE;
     }
-
-    gst_element_set_state (gnlobject, GST_STATE_NULL);
   }
 
   g_signal_handlers_disconnect_by_func (object, sort_track_elements_cb, NULL);
@@ -434,11 +452,13 @@ ges_track_dispose (GObject * object)
       (GFunc) dispose_trackelements_foreach, track);
   g_sequence_free (priv->trackelements_by_start);
   g_list_free_full (priv->gaps, (GDestroyNotify) free_gap);
+  ges_nle_object_commit (track->priv->composition, TRUE);
 
   if (priv->mixing_operation)
     gst_object_unref (priv->mixing_operation);
 
   if (priv->composition) {
+    gst_element_remove_pad (GST_ELEMENT (track), priv->srcpad);
     gst_bin_remove (GST_BIN (object), priv->composition);
     priv->composition = NULL;
   }
@@ -448,6 +468,11 @@ ges_track_dispose (GObject * object)
     priv->caps = NULL;
   }
 
+  if (priv->restriction_caps) {
+    gst_caps_unref (priv->restriction_caps);
+    priv->restriction_caps = NULL;
+  }
+
   G_OBJECT_CLASS (ges_track_parent_class)->dispose (object);
 }
 
@@ -461,6 +486,21 @@ static void
 ges_track_constructed (GObject * object)
 {
   GESTrack *self = GES_TRACK (object);
+  gchar *componame = NULL;
+
+  if (self->type == GES_TRACK_TYPE_VIDEO) {
+    componame =
+        g_strdup_printf ("video_%s", GST_OBJECT_NAME (self->priv->composition));
+  } else if (self->type == GES_TRACK_TYPE_AUDIO) {
+    componame =
+        g_strdup_printf ("audio_%s", GST_OBJECT_NAME (self->priv->composition));
+  }
+
+  if (componame) {
+    gst_object_set_name (GST_OBJECT (self->priv->composition), componame);
+
+    g_free (componame);
+  }
 
   if (!gst_bin_add (GST_BIN (self), self->priv->composition))
     GST_ERROR ("Couldn't add composition to bin !");
@@ -468,8 +508,9 @@ ges_track_constructed (GObject * object)
   if (!gst_bin_add (GST_BIN (self), self->priv->capsfilter))
     GST_ERROR ("Couldn't add capsfilter to bin !");
 
+  _ghost_nlecomposition_srcpad (self);
   if (GES_TRACK_GET_CLASS (self)->get_mixing_element) {
-    GstElement *gnlobject;
+    GstElement *nleobject;
     GstElement *mixer = GES_TRACK_GET_CLASS (self)->get_mixing_element (self);
 
     if (mixer == NULL) {
@@ -478,24 +519,24 @@ ges_track_constructed (GObject * object)
       return;
     }
 
-    gnlobject = gst_element_factory_make ("gnloperation", "mixing-operation");
-    if (!gst_bin_add (GST_BIN (gnlobject), mixer)) {
+    nleobject = gst_element_factory_make ("nleoperation", "mixing-operation");
+    if (!gst_bin_add (GST_BIN (nleobject), mixer)) {
       GST_WARNING_OBJECT (self, "Could not add the mixer to our composition");
-      gst_object_unref (gnlobject);
+      gst_object_unref (nleobject);
 
       return;
     }
-    g_object_set (gnlobject, "expandable", TRUE, NULL);
+    g_object_set (nleobject, "expandable", TRUE, NULL);
 
     if (self->priv->mixing) {
-      if (!gst_bin_add (GST_BIN (self->priv->composition), gnlobject)) {
+      if (!ges_nle_composition_add_object (self->priv->composition, nleobject)) {
         GST_WARNING_OBJECT (self, "Could not add the mixer to our composition");
 
         return;
       }
     }
 
-    self->priv->mixing_operation = gst_object_ref (gnlobject);
+    self->priv->mixing_operation = gst_object_ref (nleobject);
 
   } else {
     GST_INFO_OBJECT (self, "No way to create a main mixer");
@@ -506,6 +547,7 @@ static void
 ges_track_class_init (GESTrackClass * klass)
 {
   GObjectClass *object_class = G_OBJECT_CLASS (klass);
+  GstElementClass *gstelement_class = (GstElementClass *) klass;
 
   g_type_class_add_private (klass, sizeof (GESTrackPrivate));
 
@@ -584,6 +626,9 @@ ges_track_class_init (GESTrackClass * klass)
   g_object_class_install_property (object_class, ARG_MIXING,
       properties[ARG_MIXING]);
 
+  gst_element_class_add_pad_template (gstelement_class,
+      gst_static_pad_template_get (&ges_track_src_pad_template));
+
   /**
    * GESTrack::track-element-added:
    * @object: the #GESTrack
@@ -608,6 +653,14 @@ ges_track_class_init (GESTrackClass * klass)
       G_SIGNAL_RUN_FIRST, 0, NULL, NULL, g_cclosure_marshal_generic,
       G_TYPE_NONE, 1, GES_TYPE_TRACK_ELEMENT);
 
+  /**
+   * GESTrack::commited:
+   * @track: the #GESTrack
+   */
+  ges_track_signals[COMMITED] =
+      g_signal_new ("commited", G_TYPE_FROM_CLASS (klass),
+      G_SIGNAL_RUN_LAST, 0, NULL, NULL, NULL, G_TYPE_NONE, 0);
+
   klass->get_mixing_element = NULL;
 }
 
@@ -617,7 +670,7 @@ ges_track_init (GESTrack * self)
   self->priv = G_TYPE_INSTANCE_GET_PRIVATE (self,
       GES_TYPE_TRACK, GESTrackPrivate);
 
-  self->priv->composition = gst_element_factory_make ("gnlcomposition", NULL);
+  self->priv->composition = gst_element_factory_make ("nlecomposition", NULL);
   self->priv->capsfilter = gst_element_factory_make ("capsfilter", NULL);
   self->priv->updating = TRUE;
   self->priv->trackelements_by_start = g_sequence_new (NULL);
@@ -630,10 +683,8 @@ ges_track_init (GESTrack * self)
 
   g_signal_connect (G_OBJECT (self->priv->composition), "notify::duration",
       G_CALLBACK (composition_duration_cb), self);
-  g_signal_connect (self->priv->composition, "pad-added",
-      (GCallback) pad_added_cb, self);
-  g_signal_connect (self->priv->composition, "pad-removed",
-      (GCallback) pad_removed_cb, self);
+  g_signal_connect (G_OBJECT (self->priv->composition), "commited",
+      G_CALLBACK (composition_commited_cb), self);
 }
 
 /**
@@ -657,6 +708,7 @@ ges_track_new (GESTrackType type, GstCaps * caps)
   /* TODO Be smarter with well known track types */
   if (type == GES_TRACK_TYPE_VIDEO) {
     tmpcaps = gst_caps_new_empty_simple ("video/x-raw");
+    gst_caps_set_features (tmpcaps, 0, gst_caps_features_new_any ());
 
     if (gst_caps_is_subset (caps, tmpcaps)) {
       track = GES_TRACK (ges_video_track_new ());
@@ -668,6 +720,7 @@ ges_track_new (GESTrackType type, GstCaps * caps)
     gst_caps_unref (tmpcaps);
   } else if (type == GES_TRACK_TYPE_AUDIO) {
     tmpcaps = gst_caps_new_empty_simple ("audio/x-raw");
+    gst_caps_set_features (tmpcaps, 0, gst_caps_features_new_any ());
 
     if (gst_caps_is_subset (caps, tmpcaps)) {
       track = GES_TRACK (ges_audio_track_new ());
@@ -700,7 +753,7 @@ ges_track_set_timeline (GESTrack * track, GESTimeline * timeline)
   GST_DEBUG ("track:%p, timeline:%p", track, timeline);
 
   track->priv->timeline = timeline;
-  resort_and_fill_gaps (track);
+  track_resort_and_fill_gaps (track);
 }
 
 /**
@@ -709,11 +762,15 @@ ges_track_set_timeline (GESTrack * track, GESTimeline * timeline)
  * @caps: the #GstCaps to set
  *
  * Sets the given @caps on the track.
+ * Note that the capsfeatures of @caps will always be set
+ * to ANY. If you want to restrict them, you should
+ * do it in #ges_track_set_restriction_caps.
  */
 void
 ges_track_set_caps (GESTrack * track, const GstCaps * caps)
 {
   GESTrackPrivate *priv;
+  gint i;
 
   g_return_if_fail (GES_IS_TRACK (track));
 
@@ -726,6 +783,9 @@ ges_track_set_caps (GESTrack * track, const GstCaps * caps)
     gst_caps_unref (priv->caps);
   priv->caps = gst_caps_copy (caps);
 
+  for (i = 0; i < (int) gst_caps_get_size (priv->caps); i++)
+    gst_caps_set_features (priv->caps, i, gst_caps_features_new_any ());
+
   g_object_set (priv->composition, "caps", caps, NULL);
   /* FIXME : update all trackelements ? */
 }
@@ -758,6 +818,40 @@ ges_track_set_restriction_caps (GESTrack * track, const GstCaps * caps)
   g_object_notify (G_OBJECT (track), "restriction-caps");
 }
 
+/**
+ * ges_track_update_restriction_caps:
+ * @track: a #GESTrack
+ * @caps: the #GstCaps to update with
+ *
+ * Updates the restriction caps by modifying all the fields present in @caps
+ * in the original restriction caps. If for example the current restriction caps
+ * are video/x-raw, format=I420, width=360 and @caps is video/x-raw, format=RGB,
+ * the restriction caps will be updated to video/x-raw, format=RGB, width=360.
+ *
+ * Modification happens for each structure in the new caps, and
+ * one can add new fields or structures through that function.
+ */
+void
+ges_track_update_restriction_caps (GESTrack * self, const GstCaps * caps)
+{
+  guint i;
+  GstCaps *new_restriction_caps = gst_caps_copy (self->priv->restriction_caps);
+
+  for (i = 0; i < gst_caps_get_size (caps); i++) {
+    GstStructure *new = gst_caps_get_structure (caps, i);
+
+    if (gst_caps_get_size (new_restriction_caps) > i) {
+      GstStructure *original = gst_caps_get_structure (new_restriction_caps, i);
+      gst_structure_foreach (new, (GstStructureForeachFunc) update_field,
+          original);
+    } else
+      gst_caps_append_structure (new_restriction_caps,
+          gst_structure_copy (new));
+  }
+
+  ges_track_set_restriction_caps (self, new_restriction_caps);
+}
+
 /**
  * ges_track_set_mixing:
  * @track: a #GESTrack
@@ -783,13 +877,13 @@ ges_track_set_mixing (GESTrack * track, gboolean mixing)
   if (mixing) {
     /* increase ref count to hold the object */
     gst_object_ref (track->priv->mixing_operation);
-    if (!gst_bin_add (GST_BIN (track->priv->composition),
+    if (!ges_nle_composition_add_object (track->priv->composition,
             track->priv->mixing_operation)) {
       GST_WARNING_OBJECT (track, "Could not add the mixer to our composition");
       return;
     }
   } else {
-    if (!gst_bin_remove (GST_BIN (track->priv->composition),
+    if (!ges_nle_composition_remove_object (track->priv->composition,
             track->priv->mixing_operation)) {
       GST_WARNING_OBJECT (track,
           "Could not remove the mixer from our composition");
@@ -834,12 +928,12 @@ ges_track_add_element (GESTrack * track, GESTrackElement * object)
   }
 
   GST_DEBUG ("Adding object %s to ourself %s",
-      GST_OBJECT_NAME (ges_track_element_get_gnlobject (object)),
+      GST_OBJECT_NAME (ges_track_element_get_nleobject (object)),
       GST_OBJECT_NAME (track->priv->composition));
 
-  if (G_UNLIKELY (!gst_bin_add (GST_BIN (track->priv->composition),
-              ges_track_element_get_gnlobject (object)))) {
-    GST_WARNING ("Couldn't add object to the GnlComposition");
+  if (G_UNLIKELY (!ges_nle_composition_add_object (track->priv->composition,
+              ges_track_element_get_nleobject (object)))) {
+    GST_WARNING ("Couldn't add object to the NleComposition");
     return FALSE;
   }
 
@@ -916,7 +1010,7 @@ ges_track_remove_element (GESTrack * track, GESTrackElement * object)
 
   it = g_hash_table_lookup (priv->trackelements_iter, object);
   g_sequence_remove (it);
-  resort_and_fill_gaps (track);
+  track_resort_and_fill_gaps (track);
 
   if (remove_object_internal (track, object) == TRUE) {
     ges_timeline_element_set_timeline (GES_TIMELINE_ELEMENT (object), NULL);
@@ -967,7 +1061,7 @@ ges_track_get_timeline (GESTrack * track)
  * ges_track_get_mixing:
  * @track: a #GESTrack
  *
- *  Gets if the underlying #GnlComposition contains an expandable mixer.
+ *  Gets if the underlying #NleComposition contains an expandable mixer.
  *
  * Returns: #True if there is a mixer, #False otherwise.
  */
@@ -987,7 +1081,7 @@ ges_track_get_mixing (GESTrack * track)
  * track.
  *
  * When timing changes happen in a timeline, the changes are not
- * directly done inside GNL. This method needs to be called so any changes
+ * directly done inside NLE. This method needs to be called so any changes
  * on a clip contained in the timeline actually happen at the media
  * processing level.
  *
@@ -997,14 +1091,11 @@ ges_track_get_mixing (GESTrack * track)
 gboolean
 ges_track_commit (GESTrack * track)
 {
-  gboolean ret;
-
   g_return_val_if_fail (GES_IS_TRACK (track), FALSE);
 
-  resort_and_fill_gaps (track);
-  g_signal_emit_by_name (track->priv->composition, "commit", TRUE, &ret);
+  track_resort_and_fill_gaps (track);
 
-  return ret;
+  return ges_nle_object_commit (track->priv->composition, TRUE);
 }
 
 
