@@ -27,12 +27,14 @@
  * let you get information about the medias. Also, the tags found in the media file are
  * set as Metadatas of the Asser.
  */
+#include <errno.h>
 #include <gst/pbutils/pbutils.h>
 #include "ges.h"
 #include "ges-internal.h"
 #include "ges-track-element-asset.h"
 
 static GHashTable *parent_newparent_table = NULL;
+
 static void
 initable_iface_init (GInitableIface * initable_iface)
 {
@@ -143,7 +145,7 @@ _request_id_update (GESAsset * self, gchar ** proposed_new_id, GError * error)
         GFile *new_file = g_file_get_child (new_parent, basename);
 
         /* FIXME Handle the GCancellable */
-        if (g_file_query_exists (file, NULL)) {
+        if (g_file_query_exists (new_file, NULL)) {
           *proposed_new_id = g_file_get_uri (new_file);
           GST_DEBUG_OBJECT (self, "Proposing path: %s as proxy",
               *proposed_new_id);
@@ -180,6 +182,8 @@ _asset_proxied (GESAsset * self, const gchar * new_uri)
 static void
 ges_uri_clip_asset_class_init (GESUriClipAssetClass * klass)
 {
+  GstClockTime timeout;
+  const gchar *timeout_str;
   GObjectClass *object_class = G_OBJECT_CLASS (klass);
   g_type_class_add_private (klass, sizeof (GESUriClipAssetPrivate));
 
@@ -202,8 +206,18 @@ ges_uri_clip_asset_class_init (GESUriClipAssetClass * klass)
   g_object_class_install_property (object_class, PROP_DURATION,
       properties[PROP_DURATION]);
 
-  klass->discoverer = gst_discoverer_new (GST_SECOND, NULL);
-  klass->sync_discoverer = gst_discoverer_new (GST_SECOND, NULL);
+  errno = 0;
+  timeout_str = g_getenv ("GES_DISCOVERY_TIMEOUT");
+  if (timeout_str)
+    timeout = g_ascii_strtod (timeout_str, NULL) * GST_SECOND;
+  else
+    errno = 10;
+
+  if (errno)
+    timeout = 60 * GST_SECOND;
+
+  klass->discoverer = gst_discoverer_new (timeout, NULL);
+  klass->sync_discoverer = gst_discoverer_new (timeout, NULL);
   g_signal_connect (klass->discoverer, "discovered",
       G_CALLBACK (discoverer_discovered_cb), NULL);
 
@@ -340,8 +354,14 @@ discoverer_discovered_cb (GstDiscoverer * discoverer,
   if (tags)
     gst_tag_list_foreach (tags, (GstTagForeachFunc) _set_meta_foreach, mfs);
 
-  if (err == NULL)
+  if (gst_discoverer_info_get_result (info) == GST_DISCOVERER_OK) {
     ges_uri_clip_asset_set_info (mfs, info);
+  } else if (!err) {
+    err = g_error_new (GST_RESOURCE_ERROR, GST_RESOURCE_ERROR_FAILED,
+        "Stream %s discovering failed (error code: %d)",
+        uri, gst_discoverer_info_get_result (info));
+  }
+
   ges_asset_cache_set_loaded (GES_TYPE_URI_CLIP, uri, err);
 }
 
@@ -491,6 +511,10 @@ ges_uri_clip_asset_request_sync (const gchar * uri, GError ** error)
     info = gst_discoverer_discover_uri (discoverer, uri, &lerror);
   }
 
+  ges_asset_cache_put (gst_object_ref (asset), NULL);
+  ges_uri_clip_asset_set_info (asset, info);
+  ges_asset_cache_set_loaded (GES_TYPE_URI_CLIP, uri, lerror);
+
   if (info == NULL || lerror != NULL) {
     gst_object_unref (asset);
     if (lerror)
@@ -499,10 +523,6 @@ ges_uri_clip_asset_request_sync (const gchar * uri, GError ** error)
     return NULL;
   }
 
-  ges_asset_cache_put (gst_object_ref (asset), NULL);
-  ges_uri_clip_asset_set_info (asset, info);
-  ges_asset_cache_set_loaded (GES_TYPE_URI_CLIP, uri, lerror);
-
   return asset;
 }
 
