@@ -161,3 +161,25 @@ ges_get_compositor_factory (void)
 
   return compositor_factory;
 }
+
+gboolean
+ges_nle_composition_add_object (GstElement * comp, GstElement * object)
+{
+  return gst_bin_add (GST_BIN (comp), object);
+}
+
+gboolean
+ges_nle_composition_remove_object (GstElement * comp, GstElement * object)
+{
+  return gst_bin_remove (GST_BIN (comp), object);
+}
+
+gboolean
+ges_nle_object_commit (GstElement * nlesource, gboolean recurse)
+{
+  gboolean ret;
+
+  g_signal_emit_by_name (nlesource, "commit", recurse, &ret);
+
+  return ret;
+}
