@@ -21,6 +21,51 @@
 /**
  * SECTION:gesvideosource
  * @short_description: Base Class for video sources
+ *
+ * <refsect1 id="GESVideoSource.children_properties" role="properties">
+ * <title role="children_properties.title">Children Properties</title>
+ * <para>You can use the following children properties through the
+ * #ges_track_element_set_child_property and alike set of methods:</para>
+ * <informaltable frame="none">
+ * <tgroup cols="3">
+ * <colspec colname="properties_type" colwidth="150px"/>
+ * <colspec colname="properties_name" colwidth="200px"/>
+ * <colspec colname="properties_flags" colwidth="400px"/>
+ * <tbody>
+ * <row>
+ *  <entry role="property_type"><link linkend="gdouble"><type>double</type></link></entry>
+ *  <entry role="property_name"><link linkend="GESVideoSource--alpha">alpha</link></entry>
+ *  <entry>The desired alpha for the stream.</entry>
+ * </row>
+ * <row>
+ *  <entry role="property_type"><link linkend="gint"><type>gint</type></link></entry>
+ *  <entry role="property_name"><link linkend="GESVideoSource--posx">posx</link></entry>
+ *  <entry>The desired x position for the stream.</entry>
+ * </row>
+ * <row>
+ *  <entry role="property_type"><link linkend="gint"><type>gint</type></link></entry>
+ *  <entry role="property_name"><link linkend="GESVideoSource--posy">posy</link></entry>
+ *  <entry>The desired y position for the stream</entry>
+ * </row>
+ * <row>
+ *  <entry role="property_type"><link linkend="guint"><type>guint</type></link></entry>
+ *  <entry role="property_name"><link linkend="GESVideoSource--zorder">zorder</link></entry>
+ *  <entry>The desired z order for the stream</entry>
+ * </row>
+ * <row>
+ *  <entry role="property_type"><link linkend="gint"><type>gint</type></link></entry>
+ *  <entry role="property_name"><link linkend="GESVideoSource--width">width</link></entry>
+ *  <entry>The desired width for that source. Set to 0 if size is not mandatory, will be set to width of the current track.</entry>
+ * </row>
+ * <row>
+ *  <entry role="property_type"><link linkend="gint"><type>gint</type></link></entry>
+ *  <entry role="property_name"><link linkend="GESVideoSource--height">height</link></entry>
+ *  <entry>The desired height for that source. Set to 0 if size is not mandatory, will be set to height of the current track.</entry>
+ * </row>
+ * </tbody>
+ * </tgroup>
+ * </informaltable>
+ * </refsect1>
  */
 
 #include <gst/pbutils/missing-plugins.h>
@@ -32,48 +77,31 @@
 #include "ges-layer.h"
 #include "gstframepositionner.h"
 
+#define parent_class ges_video_source_parent_class
 G_DEFINE_ABSTRACT_TYPE (GESVideoSource, ges_video_source, GES_TYPE_SOURCE);
 
 struct _GESVideoSourcePrivate
 {
   GstFramePositionner *positionner;
   GstElement *capsfilter;
-  GESLayer *layer;
 };
 
 /* TrackElement VMethods */
-static void
-layer_priority_changed_cb (GESLayer * layer, GParamSpec * arg G_GNUC_UNUSED,
-    GESVideoSource * self)
+
+static gboolean
+_set_priority (GESTimelineElement * element, guint32 priority)
 {
-  g_object_set (self->priv->positionner, "zorder",
-      10000 - ges_layer_get_priority (layer), NULL);
-}
+  gboolean res;
+  GESVideoSource *self = GES_VIDEO_SOURCE (element);
 
-static void
-layer_changed_cb (GESClip * clip, GParamSpec * arg G_GNUC_UNUSED,
-    GESVideoSource * self)
-{
-  GESVideoSourcePrivate *priv = self->priv;
+  res = GES_TIMELINE_ELEMENT_CLASS (parent_class)->set_priority (element,
+      priority);
 
-  if (priv->layer) {
-    g_signal_handlers_disconnect_by_func (priv->layer,
-        layer_priority_changed_cb, self);
-  }
+  if (res && self->priv->positionner)
+    g_object_set (self->priv->positionner, "zorder",
+        G_MAXUINT - priority, NULL);
 
-  priv->layer = ges_clip_get_layer (clip);
-  if (priv->layer == NULL)
-    return;
-
-  /* We do not need any ref ourself as our parent owns one and we are connected
-   * to it */
-  g_object_unref (priv->layer);
-  /* 10000 is the max value of zorder on videomixerpad, hardcoded */
-  g_signal_connect (self->priv->layer, "notify::priority",
-      G_CALLBACK (layer_priority_changed_cb), self);
-
-  g_object_set (self->priv->positionner, "zorder",
-      10000 - ges_layer_get_priority (self->priv->layer), NULL);
+  return res;
 }
 
 static void
@@ -108,6 +136,8 @@ ges_video_source_create_element (GESTrackElement * trksrc)
   /* That positionner will add metadata to buffers according to its
      properties, acting like a proxy for our smart-mixer dynamic pads. */
   positionner = gst_element_factory_make ("framepositionner", "frame_tagger");
+  g_object_set (positionner, "zorder",
+      G_MAXUINT - GES_TIMELINE_ELEMENT_PRIORITY (self), NULL);
 
   videoscale =
       gst_element_factory_make ("videoscale", "track-element-videoscale");
@@ -145,9 +175,6 @@ ges_video_source_create_element (GESTrackElement * trksrc)
   parent = ges_timeline_element_get_parent (GES_TIMELINE_ELEMENT (trksrc));
   if (parent) {
     self->priv->positionner = GST_FRAME_POSITIONNER (positionner);
-    g_signal_connect (parent, "notify::layer",
-        (GCallback) layer_changed_cb, trksrc);
-    layer_changed_cb (GES_CLIP (parent), NULL, self);
     gst_object_unref (parent);
   } else {
     GST_ERROR ("No parent timeline element, SHOULD NOT HAPPEN");
@@ -158,28 +185,6 @@ ges_video_source_create_element (GESTrackElement * trksrc)
   return topbin;
 }
 
-static gboolean
-_set_parent (GESTimelineElement * self, GESTimelineElement * parent)
-{
-  GESVideoSourcePrivate *priv = GES_VIDEO_SOURCE (self)->priv;
-
-  if (self->parent) {
-    if (priv->layer) {
-      g_signal_handlers_disconnect_by_func (priv->layer,
-          layer_priority_changed_cb, self);
-      priv->layer = NULL;
-    }
-
-    g_signal_handlers_disconnect_by_func (self->parent, layer_changed_cb, self);
-  }
-
-  if (parent && priv->positionner)
-    layer_changed_cb (GES_CLIP (parent), NULL, GES_VIDEO_SOURCE (self));
-
-
-  return TRUE;
-}
-
 static void
 ges_video_source_class_init (GESVideoSourceClass * klass)
 {
@@ -189,8 +194,9 @@ ges_video_source_class_init (GESVideoSourceClass * klass)
 
   g_type_class_add_private (klass, sizeof (GESVideoSourcePrivate));
 
-  element_class->set_parent = _set_parent;
-  track_class->gnlobject_factorytype = "gnlsource";
+  element_class->set_priority = _set_priority;
+
+  track_class->nleobject_factorytype = "nlesource";
   track_class->create_element = ges_video_source_create_element;
   video_source_class->create_source = NULL;
 }
