@@ -25,9 +25,11 @@
 
 #include <ges/ges.h>
 #include "ges-internal.h"
+#include "ges-smart-video-mixer.h"
 
 #include <gst/controller/gstdirectcontrolbinding.h>
 
+#define parent_class ges_video_transition_parent_class
 G_DEFINE_TYPE (GESVideoTransition, ges_video_transition, GES_TYPE_TRANSITION);
 
 static inline void
@@ -62,6 +64,8 @@ struct _GESVideoTransitionPrivate
   /* This is in case the smpte doesn't exist yet */
   gint pending_border_value;
   gboolean pending_inverted;
+
+  GstElement *positionner;
 };
 
 enum
@@ -104,11 +108,28 @@ duration_changed_cb (GESTrackElement * self, GParamSpec * arg G_GNUC_UNUSED)
       ges_timeline_element_get_duration (GES_TIMELINE_ELEMENT (self)));
 }
 
+static gboolean
+_set_priority (GESTimelineElement * element, guint32 priority)
+{
+  gboolean res;
+  GESVideoTransition *self = GES_VIDEO_TRANSITION (element);
+
+  res = GES_TIMELINE_ELEMENT_CLASS (parent_class)->set_priority (element,
+      priority);
+
+  if (res && self->priv->positionner)
+    g_object_set (self->priv->positionner, "zorder",
+        G_MAXUINT - priority, NULL);
+
+  return res;
+}
+
 static void
 ges_video_transition_class_init (GESVideoTransitionClass * klass)
 {
   GObjectClass *object_class;
   GESTrackElementClass *toclass;
+  GESTimelineElementClass *element_class = GES_TIMELINE_ELEMENT_CLASS (klass);
 
   g_type_class_add_private (klass, sizeof (GESVideoTransitionPrivate));
 
@@ -158,6 +179,8 @@ ges_video_transition_class_init (GESVideoTransitionClass * klass)
 
   toclass = GES_TRACK_ELEMENT_CLASS (klass);
   toclass->create_element = ges_video_transition_create_element;
+
+  element_class->set_priority = _set_priority;
 }
 
 static void
@@ -307,13 +330,18 @@ ges_video_transition_create_element (GESTrackElement * object)
 
   iconva = gst_element_factory_make ("videoconvert", "tr-csp-a");
   iconvb = gst_element_factory_make ("videoconvert", "tr-csp-b");
+  priv->positionner =
+      gst_element_factory_make ("framepositionner", "frame_tagger");
+  g_object_set (priv->positionner, "zorder",
+      G_MAXUINT - GES_TIMELINE_ELEMENT_PRIORITY (self), NULL);
   oconv = gst_element_factory_make ("videoconvert", "tr-csp-output");
 
-  gst_bin_add_many (GST_BIN (topbin), iconva, iconvb, oconv, NULL);
+  gst_bin_add_many (GST_BIN (topbin), iconva, iconvb, priv->positionner,
+      oconv, NULL);
 
-  mixer = gst_element_factory_create (ges_get_compositor_factory (), NULL);
-  g_assert (mixer);
-  g_object_set (G_OBJECT (mixer), "background", 1, NULL);
+  mixer = ges_smart_mixer_new (NULL);
+  g_object_set (GES_SMART_MIXER (mixer)->mixer, "background", 3, NULL);
+  GES_SMART_MIXER (mixer)->disable_zorder_alpha = TRUE;
   gst_bin_add (GST_BIN (topbin), mixer);
 
   priv->mixer_sinka =
@@ -323,8 +351,11 @@ ges_video_transition_create_element (GESTrackElement * object)
       (GstPad *) link_element_to_mixer_with_smpte (GST_BIN (topbin), iconvb,
       mixer, GES_VIDEO_STANDARD_TRANSITION_TYPE_BAR_WIPE_LR, &priv->smpte,
       priv);
+  g_object_set (priv->mixer_sinka, "zorder", 0, NULL);
+  g_object_set (priv->mixer_sinkb, "zorder", 1, NULL);
 
-  fast_element_link (mixer, oconv);
+  fast_element_link (mixer, priv->positionner);
+  fast_element_link (priv->positionner, oconv);
 
   sinka_target = gst_element_get_static_pad (iconva, "sink");
   sinkb_target = gst_element_get_static_pad (iconvb, "sink");
@@ -372,7 +403,7 @@ link_element_to_mixer_with_smpte (GstBin * bin, GstElement * element,
     GstElement * mixer, gint type, GstElement ** smpteref,
     GESVideoTransitionPrivate * priv)
 {
-  GstPad *srcpad, *sinkpad;
+  GstPad *srcpad, *sinkpad, *mixerpad;
   GstElement *smptealpha = gst_element_factory_make ("smptealpha", NULL);
 
   g_object_set (G_OBJECT (smptealpha),
@@ -388,11 +419,11 @@ link_element_to_mixer_with_smpte (GstBin * bin, GstElement * element,
   }
 
   srcpad = gst_element_get_static_pad (smptealpha, "src");
-  sinkpad = gst_element_get_request_pad (mixer, "sink_%u");
+  sinkpad = ges_smart_mixer_get_mixer_pad (GES_SMART_MIXER (mixer), &mixerpad);
   gst_pad_link_full (srcpad, sinkpad, GST_PAD_LINK_CHECK_NOTHING);
   gst_object_unref (srcpad);
 
-  return G_OBJECT (sinkpad);
+  return G_OBJECT (mixerpad);
 }
 
 static void
