@@ -18,6 +18,7 @@
  */
 
 #include "test-utils.h"
+#include "../../../ges/ges-structured-interface.h"
 #include <ges/ges.h>
 #include <gst/check/gstcheck.h>
 
@@ -66,8 +67,8 @@ GST_START_TEST (test_object_properties)
   assert_equals_uint64 (_INPOINT (trackelement), 12);
 
   /* And let's also check that it propagated correctly to GNonLin */
-  gnl_object_check (ges_track_element_get_gnlobject (trackelement), 42, 51, 12,
-      51, MIN_GNL_PRIO, TRUE);
+  nle_object_check (ges_track_element_get_nleobject (trackelement), 42, 51, 12,
+      51, MIN_NLE_PRIO, TRUE);
 
   /* Change more properties, see if they propagate */
   g_object_set (clip, "start", (guint64) 420, "duration", (guint64) 510,
@@ -81,8 +82,8 @@ GST_START_TEST (test_object_properties)
 
   /* And let's also check that it propagated correctly to GNonLin */
   ges_timeline_commit (timeline);
-  gnl_object_check (ges_track_element_get_gnlobject (trackelement), 420, 510,
-      120, 510, MIN_GNL_PRIO + 0, TRUE);
+  nle_object_check (ges_track_element_get_nleobject (trackelement), 420, 510,
+      120, 510, MIN_NLE_PRIO + 0, TRUE);
 
 
   /* This time, we move the trackelement to see if the changes move
@@ -91,8 +92,8 @@ GST_START_TEST (test_object_properties)
   ges_timeline_commit (timeline);
   assert_equals_uint64 (_START (clip), 400);
   assert_equals_uint64 (_START (trackelement), 400);
-  gnl_object_check (ges_track_element_get_gnlobject (trackelement), 400, 510,
-      120, 510, MIN_GNL_PRIO + 0, TRUE);
+  nle_object_check (ges_track_element_get_nleobject (trackelement), 400, 510,
+      120, 510, MIN_NLE_PRIO + 0, TRUE);
 
   ges_container_remove (GES_CONTAINER (clip),
       GES_TIMELINE_ELEMENT (trackelement));
@@ -102,6 +103,179 @@ GST_START_TEST (test_object_properties)
 
 GST_END_TEST;
 
+GST_START_TEST (test_split_direct_bindings)
+{
+  GList *values;
+  GstControlSource *source;
+  GESTimeline *timeline;
+  GESClip *clip, *splitclip;
+  GstControlBinding *binding = NULL, *splitbinding;
+  GstTimedValueControlSource *splitsource;
+  GESLayer *layer;
+  GESAsset *asset;
+
+  GESTrackElement *element;
+
+  ges_init ();
+
+  fail_unless ((timeline = ges_timeline_new ()));
+  fail_unless ((layer = ges_layer_new ()));
+  fail_unless (ges_timeline_add_track (timeline,
+          GES_TRACK (ges_video_track_new ())));
+  fail_unless (ges_timeline_add_layer (timeline, layer));
+
+  asset = ges_asset_request (GES_TYPE_TEST_CLIP, NULL, NULL);
+  clip = ges_layer_add_asset (layer, asset, 0, 10 * GST_SECOND, 10 * GST_SECOND,
+      GES_TRACK_TYPE_UNKNOWN);
+
+  CHECK_OBJECT_PROPS (clip, 0 * GST_SECOND, 10 * GST_SECOND, 10 * GST_SECOND);
+  assert_equals_int (g_list_length (GES_CONTAINER_CHILDREN (clip)), 1);
+  check_layer (clip, 0);
+
+  source = gst_interpolation_control_source_new ();
+  g_object_set (source, "mode", GST_INTERPOLATION_MODE_LINEAR, NULL);
+  element = GES_CONTAINER_CHILDREN (clip)->data;
+  fail_unless (ges_track_element_set_control_source (element,
+          source, "alpha", "direct"));
+
+  gst_timed_value_control_source_set (GST_TIMED_VALUE_CONTROL_SOURCE (source),
+      10 * GST_SECOND, 0.0);
+  gst_timed_value_control_source_set (GST_TIMED_VALUE_CONTROL_SOURCE (source),
+      20 * GST_SECOND, 1.0);
+
+  binding = ges_track_element_get_control_binding (element, "alpha");
+  assert_equals_int (g_value_get_double (gst_control_binding_get_value (binding,
+              10 * GST_SECOND)), 0.0);
+  assert_equals_int (g_value_get_double (gst_control_binding_get_value (binding,
+              20 * GST_SECOND)), 1.0);
+
+  splitclip = ges_clip_split (clip, 5 * GST_SECOND);
+  CHECK_OBJECT_PROPS (splitclip, 5 * GST_SECOND, 15 * GST_SECOND,
+      5 * GST_SECOND);
+  check_layer (splitclip, 0);
+
+  splitbinding =
+      ges_track_element_get_control_binding (GES_CONTAINER_CHILDREN
+      (splitclip)->data, "alpha");
+  g_object_get (splitbinding, "control_source", &splitsource, NULL);
+
+  values =
+      gst_timed_value_control_source_get_all (GST_TIMED_VALUE_CONTROL_SOURCE
+      (splitsource));
+  assert_equals_int (g_list_length (values), 2);
+  assert_equals_uint64 (((GstTimedValue *) values->data)->timestamp,
+      15 * GST_SECOND);
+  assert_equals_float (((GstTimedValue *) values->data)->value, 0.5);
+
+  assert_equals_uint64 (((GstTimedValue *) values->next->data)->timestamp,
+      20 * GST_SECOND);
+  assert_equals_float (((GstTimedValue *) values->next->data)->value, 1.0);
+
+  values =
+      gst_timed_value_control_source_get_all (GST_TIMED_VALUE_CONTROL_SOURCE
+      (source));
+  assert_equals_int (g_list_length (values), 2);
+  assert_equals_uint64 (((GstTimedValue *) values->data)->timestamp,
+      10 * GST_SECOND);
+  assert_equals_float (((GstTimedValue *) values->data)->value, 0.0);
+
+  assert_equals_uint64 (((GstTimedValue *) values->next->data)->timestamp,
+      15 * GST_SECOND);
+  assert_equals_float (((GstTimedValue *) values->next->data)->value, 0.50);
+
+  CHECK_OBJECT_PROPS (clip, 0 * GST_SECOND, 10 * GST_SECOND, 5 * GST_SECOND);
+  check_layer (clip, 0);
+}
+
+GST_END_TEST;
+
+GST_START_TEST (test_split_direct_absolute_bindings)
+{
+  GList *values;
+  GstControlSource *source;
+  GESTimeline *timeline;
+  GESClip *clip, *splitclip;
+  GstControlBinding *binding = NULL, *splitbinding;
+  GstTimedValueControlSource *splitsource;
+  GESLayer *layer;
+  GESAsset *asset;
+
+  GESTrackElement *element;
+
+  ges_init ();
+
+  fail_unless ((timeline = ges_timeline_new ()));
+  fail_unless ((layer = ges_layer_new ()));
+  fail_unless (ges_timeline_add_track (timeline,
+          GES_TRACK (ges_video_track_new ())));
+  fail_unless (ges_timeline_add_layer (timeline, layer));
+
+  asset = ges_asset_request (GES_TYPE_TEST_CLIP, NULL, NULL);
+  clip = ges_layer_add_asset (layer, asset, 0, 10 * GST_SECOND, 10 * GST_SECOND,
+      GES_TRACK_TYPE_UNKNOWN);
+
+  CHECK_OBJECT_PROPS (clip, 0 * GST_SECOND, 10 * GST_SECOND, 10 * GST_SECOND);
+  assert_equals_int (g_list_length (GES_CONTAINER_CHILDREN (clip)), 1);
+  check_layer (clip, 0);
+
+  source = gst_interpolation_control_source_new ();
+  g_object_set (source, "mode", GST_INTERPOLATION_MODE_LINEAR, NULL);
+  element = GES_CONTAINER_CHILDREN (clip)->data;
+  fail_unless (ges_track_element_set_control_source (element,
+          source, "posx", "direct-absolute"));
+
+  gst_timed_value_control_source_set (GST_TIMED_VALUE_CONTROL_SOURCE (source),
+      10 * GST_SECOND, 0);
+  gst_timed_value_control_source_set (GST_TIMED_VALUE_CONTROL_SOURCE (source),
+      20 * GST_SECOND, 500);
+
+  binding = ges_track_element_get_control_binding (element, "posx");
+  assert_equals_int (g_value_get_int (gst_control_binding_get_value (binding,
+              10 * GST_SECOND)), 0);
+  assert_equals_int (g_value_get_int (gst_control_binding_get_value (binding,
+              20 * GST_SECOND)), 500);
+
+  splitclip = ges_clip_split (clip, 5 * GST_SECOND);
+  CHECK_OBJECT_PROPS (splitclip, 5 * GST_SECOND, 15 * GST_SECOND,
+      5 * GST_SECOND);
+  check_layer (splitclip, 0);
+
+  splitbinding =
+      ges_track_element_get_control_binding (GES_CONTAINER_CHILDREN
+      (splitclip)->data, "posx");
+  g_object_get (splitbinding, "control_source", &splitsource, NULL);
+
+  values =
+      gst_timed_value_control_source_get_all (GST_TIMED_VALUE_CONTROL_SOURCE
+      (splitsource));
+  assert_equals_int (g_list_length (values), 2);
+  assert_equals_uint64 (((GstTimedValue *) values->data)->timestamp,
+      15 * GST_SECOND);
+  assert_equals_float (((GstTimedValue *) values->data)->value, 250.0);
+
+  assert_equals_uint64 (((GstTimedValue *) values->next->data)->timestamp,
+      20 * GST_SECOND);
+  assert_equals_float (((GstTimedValue *) values->next->data)->value, 500.0);
+
+  values =
+      gst_timed_value_control_source_get_all (GST_TIMED_VALUE_CONTROL_SOURCE
+      (source));
+  assert_equals_int (g_list_length (values), 2);
+  assert_equals_uint64 (((GstTimedValue *) values->data)->timestamp,
+      10 * GST_SECOND);
+  assert_equals_float (((GstTimedValue *) values->data)->value, 0.0);
+
+  assert_equals_uint64 (((GstTimedValue *) values->next->data)->timestamp,
+      15 * GST_SECOND);
+  assert_equals_float (((GstTimedValue *) values->next->data)->value, 250.0);
+
+  CHECK_OBJECT_PROPS (clip, 0 * GST_SECOND, 10 * GST_SECOND, 5 * GST_SECOND);
+  check_layer (clip, 0);
+}
+
+GST_END_TEST;
+
+
 GST_START_TEST (test_split_object)
 {
   GESTimeline *timeline;
@@ -145,8 +319,8 @@ GST_START_TEST (test_split_object)
   assert_equals_uint64 (_INPOINT (trackelement), 12);
 
   /* And let's also check that it propagated correctly to GNonLin */
-  gnl_object_check (ges_track_element_get_gnlobject (trackelement), 42, 50, 12,
-      50, MIN_GNL_PRIO, TRUE);
+  nle_object_check (ges_track_element_get_nleobject (trackelement), 42, 50, 12,
+      50, MIN_NLE_PRIO, TRUE);
 
   splitclip = ges_clip_split (clip, 67);
   fail_unless (GES_IS_CLIP (splitclip));
@@ -463,38 +637,38 @@ GST_START_TEST (test_effects_priorities)
   fail_unless (ges_container_add (GES_CONTAINER (clip),
           GES_TIMELINE_ELEMENT (effect2)));
 
-  fail_unless_equals_int (MIN_GNL_PRIO + 0, _PRIORITY (effect));
-  fail_unless_equals_int (MIN_GNL_PRIO + 1, _PRIORITY (effect1));
-  fail_unless_equals_int (MIN_GNL_PRIO + 2, _PRIORITY (effect2));
+  fail_unless_equals_int (MIN_NLE_PRIO + 0, _PRIORITY (effect));
+  fail_unless_equals_int (MIN_NLE_PRIO + 1, _PRIORITY (effect1));
+  fail_unless_equals_int (MIN_NLE_PRIO + 2, _PRIORITY (effect2));
 
   fail_unless (ges_clip_set_top_effect_priority (clip, GES_BASE_EFFECT (effect),
           2));
-  fail_unless_equals_int (MIN_GNL_PRIO + 0, _PRIORITY (effect1));
-  fail_unless_equals_int (MIN_GNL_PRIO + 1, _PRIORITY (effect2));
-  fail_unless_equals_int (MIN_GNL_PRIO + 2, _PRIORITY (effect));
+  fail_unless_equals_int (MIN_NLE_PRIO + 0, _PRIORITY (effect1));
+  fail_unless_equals_int (MIN_NLE_PRIO + 1, _PRIORITY (effect2));
+  fail_unless_equals_int (MIN_NLE_PRIO + 2, _PRIORITY (effect));
 
   fail_unless (ges_clip_set_top_effect_priority (clip, GES_BASE_EFFECT (effect),
           0));
-  fail_unless_equals_int (MIN_GNL_PRIO + 0, _PRIORITY (effect));
-  fail_unless_equals_int (MIN_GNL_PRIO + 1, _PRIORITY (effect1));
-  fail_unless_equals_int (MIN_GNL_PRIO + 2, _PRIORITY (effect2));
+  fail_unless_equals_int (MIN_NLE_PRIO + 0, _PRIORITY (effect));
+  fail_unless_equals_int (MIN_NLE_PRIO + 1, _PRIORITY (effect1));
+  fail_unless_equals_int (MIN_NLE_PRIO + 2, _PRIORITY (effect2));
 
   fail_unless (ges_clip_move_to_layer (clip, layer1));
-  fail_unless_equals_int (LAYER_HEIGHT + MIN_GNL_PRIO + 0, _PRIORITY (effect));
-  fail_unless_equals_int (LAYER_HEIGHT + MIN_GNL_PRIO + 1, _PRIORITY (effect1));
-  fail_unless_equals_int (LAYER_HEIGHT + MIN_GNL_PRIO + 2, _PRIORITY (effect2));
+  fail_unless_equals_int (LAYER_HEIGHT + MIN_NLE_PRIO + 0, _PRIORITY (effect));
+  fail_unless_equals_int (LAYER_HEIGHT + MIN_NLE_PRIO + 1, _PRIORITY (effect1));
+  fail_unless_equals_int (LAYER_HEIGHT + MIN_NLE_PRIO + 2, _PRIORITY (effect2));
 
   fail_unless (ges_clip_set_top_effect_priority (clip, GES_BASE_EFFECT (effect),
           2));
-  fail_unless_equals_int (LAYER_HEIGHT + MIN_GNL_PRIO + 0, _PRIORITY (effect1));
-  fail_unless_equals_int (LAYER_HEIGHT + MIN_GNL_PRIO + 1, _PRIORITY (effect2));
-  fail_unless_equals_int (LAYER_HEIGHT + MIN_GNL_PRIO + 2, _PRIORITY (effect));
+  fail_unless_equals_int (LAYER_HEIGHT + MIN_NLE_PRIO + 0, _PRIORITY (effect1));
+  fail_unless_equals_int (LAYER_HEIGHT + MIN_NLE_PRIO + 1, _PRIORITY (effect2));
+  fail_unless_equals_int (LAYER_HEIGHT + MIN_NLE_PRIO + 2, _PRIORITY (effect));
 
   fail_unless (ges_clip_set_top_effect_priority (clip, GES_BASE_EFFECT (effect),
           0));
-  fail_unless_equals_int (LAYER_HEIGHT + MIN_GNL_PRIO + 0, _PRIORITY (effect));
-  fail_unless_equals_int (LAYER_HEIGHT + MIN_GNL_PRIO + 1, _PRIORITY (effect1));
-  fail_unless_equals_int (LAYER_HEIGHT + MIN_GNL_PRIO + 2, _PRIORITY (effect2));
+  fail_unless_equals_int (LAYER_HEIGHT + MIN_NLE_PRIO + 0, _PRIORITY (effect));
+  fail_unless_equals_int (LAYER_HEIGHT + MIN_NLE_PRIO + 1, _PRIORITY (effect1));
+  fail_unless_equals_int (LAYER_HEIGHT + MIN_NLE_PRIO + 2, _PRIORITY (effect2));
 
   gst_object_unref (timeline);
 }
@@ -511,6 +685,8 @@ ges_suite (void)
 
   tcase_add_test (tc_chain, test_object_properties);
   tcase_add_test (tc_chain, test_split_object);
+  tcase_add_test (tc_chain, test_split_direct_bindings);
+  tcase_add_test (tc_chain, test_split_direct_absolute_bindings);
   tcase_add_test (tc_chain, test_clip_group_ungroup);
   tcase_add_test (tc_chain, test_clip_refcount_remove_child);
   tcase_add_test (tc_chain, test_clip_find_track_element);
