@@ -64,6 +64,7 @@ GST_START_TEST (test_move_group)
   clips = g_list_prepend (clips, clip2);
   group = GES_GROUP (ges_container_group (clips));
   g_list_free (clips);
+  ASSERT_OBJECT_REFCOUNT (group, "2 ref for the timeline", 2);
 
   fail_unless (GES_IS_GROUP (group));
   ASSERT_OBJECT_REFCOUNT (group, "2 ref for the timeline", 2);
@@ -111,6 +112,7 @@ GST_START_TEST (test_move_group)
   CHECK_OBJECT_PROPS (clip1, 20, 0, 10);
   CHECK_OBJECT_PROPS (clip2, 60, 0, 60);
   CHECK_OBJECT_PROPS (group, 10, 0, 110);
+  ASSERT_OBJECT_REFCOUNT (group, "2 ref for the timeline", 2);
 
   /*
    *        0  10------------Group1---------------110
@@ -162,6 +164,7 @@ GST_START_TEST (test_move_group)
   CHECK_OBJECT_PROPS (clip1, 20, 5, 10);
   CHECK_OBJECT_PROPS (clip2, 60, 0, 50);
   CHECK_OBJECT_PROPS (group, 10, 0, 100);
+  ASSERT_OBJECT_REFCOUNT (group, "2 ref for the timeline", 2);
 
   /*
    *        0           20---Group1---------------110
@@ -196,23 +199,26 @@ GST_START_TEST (test_move_group)
   CHECK_OBJECT_PROPS (clip1, 25, 10, 5);
   CHECK_OBJECT_PROPS (clip2, 60, 0, 50);
   CHECK_OBJECT_PROPS (group, 25, 0, 85);
+  ASSERT_OBJECT_REFCOUNT (group, "2 ref for the timeline", 2);
 
   /*
-   *        0  10------------Group1---------------110
-   *            |------                            |
-   * layer:     |clip  |                           |
-   *            |-----15                           |
-   *            |----------------------------------|
-   *            0-----------------     0-----------|
-   * layer1:    |    clip1        |    |   clip2   |
-   *            |-----------------30   60----------|
-   *            |----------------------------------|
+   *        0  10------------Group1------------------110
+   *            |------                               |
+   * layer:     |clip  |                              |
+   *            |-----15                              |
+   *            |-------------------------------------|
+   *            |          10------      0------------|
+   * layer1:    |          | clip1 |      |  clip2    |
+   *            |         25------30      60----------|
+   *            |          |--------------------------|
+   *            |-------------------------------------|
    */
   ges_timeline_element_trim (GES_TIMELINE_ELEMENT (group), 10);
   CHECK_OBJECT_PROPS (clip, 10, 0, 5);
-  CHECK_OBJECT_PROPS (clip1, 10, 0, 20);
+  CHECK_OBJECT_PROPS (clip1, 25, 10, 5);
   CHECK_OBJECT_PROPS (clip2, 60, 0, 50);
   CHECK_OBJECT_PROPS (group, 10, 0, 100);
+  ASSERT_OBJECT_REFCOUNT (group, "2 ref for the timeline", 2);
 
   /*
    *        0             25---Group1---------------110
@@ -220,16 +226,17 @@ GST_START_TEST (test_move_group)
    * layer:         15     |                          |
    *                 |clip |                          |
    *                 -     |--------------------------|
-   *                       15------      0------------|
+   *                       10------      0------------|
    * layer1:               | clip1 |      |  clip2    |
    *                      25------30      60----------|
    *                       |--------------------------|
    */
   ges_timeline_element_trim (GES_TIMELINE_ELEMENT (group), 25);
   CHECK_OBJECT_PROPS (clip, 15, 5, 0);
-  CHECK_OBJECT_PROPS (clip1, 25, 15, 5);
+  CHECK_OBJECT_PROPS (clip1, 25, 10, 5);
   CHECK_OBJECT_PROPS (clip2, 60, 0, 50);
   CHECK_OBJECT_PROPS (group, 25, 0, 85);
+  ASSERT_OBJECT_REFCOUNT (group, "2 ref for the timeline", 2);
 
   /*
    *        0             25---Group1--30
@@ -244,7 +251,7 @@ GST_START_TEST (test_move_group)
    */
   ges_timeline_element_set_duration (GES_TIMELINE_ELEMENT (group), 10);
   CHECK_OBJECT_PROPS (clip, 15, 5, 0);
-  CHECK_OBJECT_PROPS (clip1, 25, 15, 5);
+  CHECK_OBJECT_PROPS (clip1, 25, 10, 5);
   CHECK_OBJECT_PROPS (clip2, 60, 0, 0);
   CHECK_OBJECT_PROPS (group, 25, 0, 5);
 
@@ -254,16 +261,17 @@ GST_START_TEST (test_move_group)
    * layer:        15      |                          |
    *                |clip  |                          |
    *                -      |--------------------------|
-   *                       15-------------------------|
+   *                       10-------------------------|
    * layer1:               |  clip1       |  clip2    |
    *                      25--------------60----------|
    *                       |--------------------------|
    */
   ges_timeline_element_set_duration (GES_TIMELINE_ELEMENT (group), 100);
   CHECK_OBJECT_PROPS (clip, 15, 5, 0);
-  CHECK_OBJECT_PROPS (clip1, 25, 15, 100);
+  CHECK_OBJECT_PROPS (clip1, 25, 10, 100);
   CHECK_OBJECT_PROPS (clip2, 60, 0, 65);
   CHECK_OBJECT_PROPS (group, 25, 0, 100);
+  ASSERT_OBJECT_REFCOUNT (group, "2 ref for the timeline", 2);
 
   /*
    *        0           20---Group1---------------120
@@ -271,14 +279,14 @@ GST_START_TEST (test_move_group)
    * layer:        15   |                          |
    *               |clip|                          |
    *               -    |--------------------------|
-   *                    15-------------------------|
+   *                    10-------------------------|
    * layer1:            |  clip1       |  clip2    |
    *                    20-------------55----------|
    *                    |--------------------------|
    */
   ges_timeline_element_set_start (GES_TIMELINE_ELEMENT (group), 20);
   CHECK_OBJECT_PROPS (clip, 15, 5, 0);
-  CHECK_OBJECT_PROPS (clip1, 20, 15, 100);
+  CHECK_OBJECT_PROPS (clip1, 20, 10, 100);
   CHECK_OBJECT_PROPS (clip2, 55, 0, 65);
   CHECK_OBJECT_PROPS (group, 20, 0, 100);
 
@@ -295,7 +303,7 @@ GST_START_TEST (test_move_group)
    */
   ges_timeline_element_trim (GES_TIMELINE_ELEMENT (group), 10);
   CHECK_OBJECT_PROPS (clip, 10, 0, 5);
-  CHECK_OBJECT_PROPS (clip1, 10, 5, 110);
+  CHECK_OBJECT_PROPS (clip1, 10, 0, 110);
   CHECK_OBJECT_PROPS (clip2, 55, 0, 65);
   CHECK_OBJECT_PROPS (group, 10, 0, 110);
 
@@ -487,6 +495,144 @@ GST_START_TEST (test_group_in_group)
 
 GST_END_TEST;
 
+static guint32
+ges_clip_get_layer_priority (GESClip * clip)
+{
+  GESLayer *layer = ges_clip_get_layer (clip);
+  if (layer == NULL)
+    return -1;
+
+  return ges_layer_get_priority (layer);
+}
+
+GST_START_TEST (test_group_in_group_layer_moving)
+{
+  GESAsset *asset;
+  GESTimeline *timeline;
+  GESGroup *group;
+  GESLayer *layer, *layer1, *layer2, *layer3;
+  GESClip *c, *c1;
+
+  GList *clips = NULL;
+
+  ges_init ();
+
+  timeline = ges_timeline_new_audio_video ();
+
+  /* Our timeline
+   *
+   *    --0------------10-Group-----20
+   *      | +-----------+           |
+   * L    | |    C      |           |
+   *      | +-----------+           |
+   *    --|--------------------------
+   *      |            +------------+
+   * L1   |            |     C1     |
+   *      |            +------------+
+   *    -----------------------------
+   */
+
+  layer = ges_timeline_append_layer (timeline);
+  layer1 = ges_timeline_append_layer (timeline);
+  layer2 = ges_timeline_append_layer (timeline);
+  layer3 = ges_timeline_append_layer (timeline);
+  fail_unless (layer2 && layer3);
+  assert_equals_int (ges_layer_get_priority (layer3), 3);
+  asset = ges_asset_request (GES_TYPE_TEST_CLIP, NULL, NULL);
+
+  c = ges_layer_add_asset (layer, asset, 0, 0, 10, GES_TRACK_TYPE_UNKNOWN);
+  c1 = ges_layer_add_asset (layer1, asset, 10, 0, 10, GES_TRACK_TYPE_UNKNOWN);
+  clips = g_list_prepend (clips, c);
+  clips = g_list_prepend (clips, c1);
+  group = GES_GROUP (ges_container_group (clips));
+  fail_unless (GES_TIMELINE_ELEMENT_TIMELINE (group) == timeline);
+  g_list_free (clips);
+
+  fail_unless (GES_IS_GROUP (group));
+  CHECK_OBJECT_PROPS (c, 0, 0, 10);
+  CHECK_OBJECT_PROPS (c1, 10, 0, 10);
+  CHECK_OBJECT_PROPS (group, 0, 0, 20);
+
+  /* Our timeline
+   *
+   *    --0--------10-----------20-Group----30
+   *      |         +-----------+           |
+   * L    |         |    C      |           |
+   *      |         +-----------+           |
+   *    --|-----------------------------------
+   *      |                    +------------+
+   * L1   |                    |     C1     |
+   *      |                    +------------+
+   *    -------------------------------------
+   */
+  fail_unless (ges_container_edit (GES_CONTAINER (c), NULL,
+          -1, GES_EDIT_MODE_NORMAL, GES_EDGE_NONE, 10));
+
+  CHECK_OBJECT_PROPS (c, 10, 0, 10);
+  CHECK_OBJECT_PROPS (c1, 20, 0, 10);
+  CHECK_OBJECT_PROPS (group, 10, 0, 20);
+  assert_equals_int (ges_clip_get_layer_priority (c), 0);
+  assert_equals_int (ges_clip_get_layer_priority (c1), 1);
+
+  ges_layer_set_priority (layer2, 0);
+  ges_layer_set_priority (layer, 1);
+  ges_layer_set_priority (layer1, 2);
+
+  assert_equals_int (ges_clip_get_layer_priority (c), 1);
+  assert_equals_int (ges_clip_get_layer_priority (c1), 2);
+
+  /* Our timeline
+   *
+   *    --0--------10-----------20-Group----30
+   *      |         +-----------+           |
+   * L2   |         |    C      |           |
+   *      |         +-----------+           |
+   *    --|-----------------------------------
+   *      |                    +------------+
+   * L    |                    |     C1     |
+   *      |                    +------------+
+   *    -------------------------------------
+   *
+   * L1
+   *    -------------------------------------
+   */
+  fail_unless (ges_container_edit (GES_CONTAINER (c), NULL,
+          0, GES_EDIT_MODE_NORMAL, GES_EDGE_NONE, 10));
+  CHECK_OBJECT_PROPS (c, 10, 0, 10);
+  CHECK_OBJECT_PROPS (c1, 20, 0, 10);
+  CHECK_OBJECT_PROPS (group, 10, 0, 20);
+  assert_equals_int (ges_clip_get_layer_priority (c), 0);
+  assert_equals_int (ges_clip_get_layer_priority (c1), 1);
+
+  /* Our timeline
+   *
+   *    --0--------10-----------20-Group----30
+   * L2   |                                 |
+   *   --------------------------------------
+   *      |         +-----------+           |
+   * L    |         |    C      |           |
+   *      |         +-----------+           |
+   *    --|-----------------------------------
+   *      |                    +------------+
+   * L1   |                    |     C1     |
+   *      |                    +------------+
+   *    -------------------------------------
+   */
+  fail_unless (ges_container_edit (GES_CONTAINER (c), NULL,
+          1, GES_EDIT_MODE_NORMAL, GES_EDGE_NONE, 10));
+  CHECK_OBJECT_PROPS (c, 10, 0, 10);
+  CHECK_OBJECT_PROPS (c1, 20, 0, 10);
+  CHECK_OBJECT_PROPS (group, 10, 0, 20);
+  assert_equals_int (ges_clip_get_layer_priority (c), 1);
+  assert_equals_int (ges_clip_get_layer_priority (c1), 2);
+
+  gst_object_unref (timeline);
+  gst_object_unref (asset);
+}
+
+GST_END_TEST;
+
+
 GST_START_TEST (test_group_in_self)
 {
   GESLayer *layer;
@@ -525,6 +671,93 @@ GST_START_TEST (test_group_in_self)
 
 GST_END_TEST;
 
+static void
+project_loaded_cb (GESProject * project, GESTimeline * timeline,
+    GMainLoop * mainloop)
+{
+  GST_ERROR ("LOADED!");
+  g_main_loop_quit (mainloop);
+}
+
+GST_START_TEST (test_group_serialization)
+{
+  gchar *tmpuri;
+  GESLayer *layer;
+  GESClip *c, *c1, *c2, *c3;
+  GESAsset *asset;
+  GESTimeline *timeline;
+  GESGroup *group;
+  GESProject *project;
+  GMainLoop *mainloop;
+
+  GError *err = NULL;
+  GList *tmp, *clips = NULL;
+
+  ges_init ();
+
+  timeline = ges_timeline_new_audio_video ();
+
+  layer = ges_timeline_append_layer (timeline);
+  asset = ges_asset_request (GES_TYPE_TEST_CLIP, NULL, NULL);
+
+  c = ges_layer_add_asset (layer, asset, 0, 0, 10, GES_TRACK_TYPE_UNKNOWN);
+
+  c1 = ges_layer_add_asset (layer, asset, 10, 0, 10, GES_TRACK_TYPE_UNKNOWN);
+
+  clips = g_list_prepend (clips, c);
+  clips = g_list_prepend (clips, c1);
+
+  c2 = ges_layer_add_asset (layer, asset, 20, 0, 10, GES_TRACK_TYPE_UNKNOWN);
+
+  c3 = ges_layer_add_asset (layer, asset, 30, 0, 10, GES_TRACK_TYPE_UNKNOWN);
+
+  group = GES_GROUP (ges_container_group (clips));
+  fail_unless (GES_TIMELINE_ELEMENT_TIMELINE (group) == timeline);
+  g_list_free (clips);
+
+
+  clips = g_list_append (NULL, group);
+  clips = g_list_append (clips, c2);
+  group = GES_GROUP (ges_container_group (clips));
+  fail_unless (GES_TIMELINE_ELEMENT_TIMELINE (group) == timeline);
+  g_list_free (clips);
+
+  clips = g_list_append (NULL, group);
+  clips = g_list_append (clips, c3);
+  group = GES_GROUP (ges_container_group (clips));
+  fail_unless (GES_TIMELINE_ELEMENT_TIMELINE (group) == timeline);
+  g_list_free (clips);
+
+  project =
+      GES_PROJECT (ges_extractable_get_asset (GES_EXTRACTABLE (timeline)));
+
+  tmpuri = ges_test_get_tmp_uri ("test-auto-transition-save.xges");
+  fail_unless (ges_project_save (project, timeline, tmpuri, NULL, TRUE, NULL));
+  gst_object_unref (timeline);
+  gst_object_unref (asset);
+
+  project = ges_project_new (tmpuri);
+  mainloop = g_main_loop_new (NULL, FALSE);
+  g_signal_connect (project, "loaded", (GCallback) project_loaded_cb, mainloop);
+  timeline = GES_TIMELINE (ges_asset_extract (GES_ASSET (project), &err));
+  g_main_loop_run (mainloop);
+
+  fail_unless (err == NULL, "%s", err ? err->message : "Nothing");
+  fail_unless (timeline != NULL);
+
+  layer = timeline->layers->data;
+  for (tmp = ges_layer_get_clips (layer); tmp; tmp = tmp->next) {
+    fail_unless (GES_IS_GROUP (GES_TIMELINE_ELEMENT_PARENT (tmp->data)),
+        "%s parent is %p, NOT a group", GES_TIMELINE_ELEMENT_NAME (tmp->data),
+        GES_TIMELINE_ELEMENT_PARENT (tmp->data));
+  }
+
+
+  g_free (tmpuri);
+}
+
+GST_END_TEST;
+
 static Suite *
 ges_suite (void)
 {
@@ -536,6 +769,8 @@ ges_suite (void)
   tcase_add_test (tc_chain, test_move_group);
   tcase_add_test (tc_chain, test_group_in_group);
   tcase_add_test (tc_chain, test_group_in_self);
+  tcase_add_test (tc_chain, test_group_serialization);
+  tcase_add_test (tc_chain, test_group_in_group_layer_moving);
 
   return s;
 }
