@@ -74,32 +74,32 @@ GST_START_TEST (test_layer_properties)
   assert_equals_uint64 (_INPOINT (clip), 12);
   assert_equals_uint64 (_PRIORITY (clip), 0);
   ges_timeline_commit (timeline);
-  gnl_object_check (ges_track_element_get_gnlobject (trackelement), 42, 51, 12,
-      51, MIN_GNL_PRIO, TRUE);
+  nle_object_check (ges_track_element_get_nleobject (trackelement), 42, 51, 12,
+      51, MIN_NLE_PRIO, TRUE);
 
   /* Change the priority of the layer */
   g_object_set (layer, "priority", 1, NULL);
   assert_equals_int (ges_layer_get_priority (layer), 1);
   assert_equals_uint64 (_PRIORITY (clip), 0);
   ges_timeline_commit (timeline);
-  gnl_object_check (ges_track_element_get_gnlobject (trackelement), 42, 51, 12,
-      51, LAYER_HEIGHT + MIN_GNL_PRIO, TRUE);
+  nle_object_check (ges_track_element_get_nleobject (trackelement), 42, 51, 12,
+      51, LAYER_HEIGHT + MIN_NLE_PRIO, TRUE);
 
   /* Change it to an insanely high value */
   g_object_set (layer, "priority", 31, NULL);
   assert_equals_int (ges_layer_get_priority (layer), 31);
   assert_equals_uint64 (_PRIORITY (clip), 0);
   ges_timeline_commit (timeline);
-  gnl_object_check (ges_track_element_get_gnlobject (trackelement), 42, 51, 12,
-      51, MIN_GNL_PRIO + LAYER_HEIGHT * 31, TRUE);
+  nle_object_check (ges_track_element_get_nleobject (trackelement), 42, 51, 12,
+      51, MIN_NLE_PRIO + LAYER_HEIGHT * 31, TRUE);
 
   /* and back to 0 */
   g_object_set (layer, "priority", 0, NULL);
   assert_equals_int (ges_layer_get_priority (layer), 0);
   assert_equals_uint64 (_PRIORITY (clip), 0);
   ges_timeline_commit (timeline);
-  gnl_object_check (ges_track_element_get_gnlobject (trackelement), 42, 51, 12,
-      51, MIN_GNL_PRIO + 0, TRUE);
+  nle_object_check (ges_track_element_get_nleobject (trackelement), 42, 51, 12,
+      51, MIN_NLE_PRIO + 0, TRUE);
 
   gst_object_unref (trackelement);
   fail_unless (ges_layer_remove_clip (layer, clip));
@@ -117,7 +117,7 @@ GST_START_TEST (test_layer_priorities)
   GESLayer *layer1, *layer2, *layer3;
   GESTrackElement *trackelement1, *trackelement2, *trackelement3;
   GESClip *clip1, *clip2, *clip3;
-  GstElement *gnlobj1, *gnlobj2, *gnlobj3;
+  GstElement *nleobj1, *nleobj2, *nleobj3;
   guint prio1, prio2, prio3;
   GList *objs, *tmp;
 
@@ -179,25 +179,25 @@ GST_START_TEST (test_layer_priorities)
 
   ges_timeline_commit (timeline);
   assert_equals_int (_PRIORITY (clip1), 0);
-  gnlobj1 = ges_track_element_get_gnlobject (trackelement1);
-  fail_unless (gnlobj1 != NULL);
-  g_object_get (gnlobj1, "priority", &prio1, NULL);
-  assert_equals_int (prio1, MIN_GNL_PRIO);
+  nleobj1 = ges_track_element_get_nleobject (trackelement1);
+  fail_unless (nleobj1 != NULL);
+  g_object_get (nleobj1, "priority", &prio1, NULL);
+  assert_equals_int (prio1, MIN_NLE_PRIO);
 
   assert_equals_int (_PRIORITY (clip2), 1);
-  gnlobj2 = ges_track_element_get_gnlobject (trackelement2);
-  fail_unless (gnlobj2 != NULL);
-  g_object_get (gnlobj2, "priority", &prio2, NULL);
+  nleobj2 = ges_track_element_get_nleobject (trackelement2);
+  fail_unless (nleobj2 != NULL);
+  g_object_get (nleobj2, "priority", &prio2, NULL);
   /* clip2 is on the second layer and has a priority of 1 */
-  assert_equals_int (prio2, MIN_GNL_PRIO + LAYER_HEIGHT + 1);
+  assert_equals_int (prio2, MIN_NLE_PRIO + LAYER_HEIGHT + 1);
 
   assert_equals_int (_PRIORITY (clip3), LAYER_HEIGHT - 1);
-  gnlobj3 = ges_track_element_get_gnlobject (trackelement3);
-  fail_unless (gnlobj3 != NULL);
+  nleobj3 = ges_track_element_get_nleobject (trackelement3);
+  fail_unless (nleobj3 != NULL);
   /* clip3 is on the third layer and has a priority of LAYER_HEIGHT + 1
    * it priority must have the maximum priority of this layer*/
-  g_object_get (gnlobj3, "priority", &prio3, NULL);
-  assert_equals_int (prio3, MIN_GNL_PRIO + LAYER_HEIGHT * 3 - 1);
+  g_object_get (nleobj3, "priority", &prio3, NULL);
+  assert_equals_int (prio3, MIN_NLE_PRIO + LAYER_HEIGHT * 3 - 1);
 
   /* Move layers around */
   g_object_set (layer1, "priority", 2, NULL);
@@ -212,12 +212,12 @@ GST_START_TEST (test_layer_priorities)
   assert_equals_int (_PRIORITY (clip1), 0);
   assert_equals_int (_PRIORITY (clip2), 1);
   assert_equals_int (_PRIORITY (clip3), LAYER_HEIGHT - 1);
-  g_object_get (gnlobj1, "priority", &prio1, NULL);
-  g_object_get (gnlobj2, "priority", &prio2, NULL);
-  g_object_get (gnlobj3, "priority", &prio3, NULL);
-  assert_equals_int (prio1, 2 * LAYER_HEIGHT + MIN_GNL_PRIO);
-  assert_equals_int (prio2, MIN_GNL_PRIO + 1);
-  assert_equals_int (prio3, LAYER_HEIGHT * 2 - 1 + MIN_GNL_PRIO);
+  g_object_get (nleobj1, "priority", &prio1, NULL);
+  g_object_get (nleobj2, "priority", &prio2, NULL);
+  g_object_get (nleobj3, "priority", &prio3, NULL);
+  assert_equals_int (prio1, 2 * LAYER_HEIGHT + MIN_NLE_PRIO);
+  assert_equals_int (prio2, MIN_NLE_PRIO + 1);
+  assert_equals_int (prio3, LAYER_HEIGHT * 2 - 1 + MIN_NLE_PRIO);
 
   /* And move objects around */
   fail_unless (ges_clip_move_to_layer (clip2, layer1));
@@ -238,12 +238,12 @@ GST_START_TEST (test_layer_priorities)
   assert_equals_int (_PRIORITY (clip1), 0);
   assert_equals_int (_PRIORITY (clip2), 1);
   assert_equals_int (_PRIORITY (clip3), LAYER_HEIGHT - 1);
-  g_object_get (gnlobj1, "priority", &prio1, NULL);
-  g_object_get (gnlobj2, "priority", &prio2, NULL);
-  g_object_get (gnlobj3, "priority", &prio3, NULL);
-  assert_equals_int (prio1, 2 * LAYER_HEIGHT + MIN_GNL_PRIO);
-  assert_equals_int (prio2, 2 * LAYER_HEIGHT + 1 + MIN_GNL_PRIO);
-  assert_equals_int (prio3, LAYER_HEIGHT * 3 - 1 + MIN_GNL_PRIO);
+  g_object_get (nleobj1, "priority", &prio1, NULL);
+  g_object_get (nleobj2, "priority", &prio2, NULL);
+  g_object_get (nleobj3, "priority", &prio3, NULL);
+  assert_equals_int (prio1, 2 * LAYER_HEIGHT + MIN_NLE_PRIO);
+  assert_equals_int (prio2, 2 * LAYER_HEIGHT + 1 + MIN_NLE_PRIO);
+  assert_equals_int (prio3, LAYER_HEIGHT * 3 - 1 + MIN_NLE_PRIO);
 
   /* And change TrackElement-s priorities and check that changes are not
    * refected on it containing Clip
@@ -252,7 +252,7 @@ GST_START_TEST (test_layer_priorities)
    * ges_timeline_element_set_priority (GES_TIMELINE_ELEMENT (trackelement3),
    * ges_timeline_commit (timeline);
    *     LAYER_HEIGHT * 2);
-   * g_object_get (gnlobj3, "priority", &prio3, NULL);
+   * g_object_get (nleobj3, "priority", &prio3, NULL);
    * assert_equals_int (prio3, 2 * LAYER_HEIGHT);
    * assert_equals_int (_PRIORITY (clip3), LAYER_HEIGHT - 1); */
 
@@ -671,18 +671,18 @@ GST_START_TEST (test_single_layer_automatic_transition)
   fail_unless (current->data == src2);
   g_list_free_full (objects, gst_object_unref);
 
-  GST_DEBUG ("Set third clip start to 1000, Transition should be updated");
-  ges_container_edit (GES_CONTAINER (src2), NULL, -1,
-      GES_EDIT_MODE_NORMAL, GES_EDGE_START, 1000);
-  ges_timeline_commit (timeline);
-  /*             600____src___1100
-   *                       !_tr__^
+  GST_DEBUG ("Check that we can not create 2 transitions at the same place");
+  fail_if (ges_container_edit (GES_CONTAINER (src2), NULL, -1,
+          GES_EDIT_MODE_NORMAL, GES_EDGE_START, 1000));
+
+  /*
    *        500___________src1________1250
    *                       1000___________src2________2000
    *                       ^____trans____^
    */
-  assert_equals_uint64 (_START (src), 600);
-  assert_equals_uint64 (_DURATION (src), 500);
+  ges_layer_remove_clip (layer, GES_CLIP (src));
+  fail_unless (ges_container_edit (GES_CONTAINER (src2), NULL, -1,
+          GES_EDIT_MODE_NORMAL, GES_EDGE_START, 1000));
   assert_equals_uint64 (_START (src1), 500);
   assert_equals_uint64 (_DURATION (src1), 1250 - 500);
   assert_equals_uint64 (_START (src2), 1000);
@@ -690,39 +690,30 @@ GST_START_TEST (test_single_layer_automatic_transition)
 
   current = objects = ges_layer_get_clips (layer);
   current = objects;
-  assert_equals_int (g_list_length (objects), 7);
+  assert_equals_int (g_list_length (objects), 4);
+  assert_is_type (objects->data, GES_TYPE_TEST_CLIP);
+  transition = objects->next->data;
+  assert_is_type (transition, GES_TYPE_TRANSITION_CLIP);
+  fail_unless (current->data == src1);
+  g_list_free_full (objects, gst_object_unref);
+
+  /*
+   *        500___________src1________1250
+   *                       ^____trans____^
+   *                       1100___________src2________2000
+   */
+  ges_container_edit (GES_CONTAINER (transition),
+      NULL, -1, GES_EDIT_MODE_TRIM, GES_EDGE_START, 1100);
+  assert_equals_uint64 (_START (src1), 500);
+  assert_equals_uint64 (_DURATION (src1), 1250 - 500);
+  assert_equals_uint64 (_START (src2), 1100);
+  assert_equals_uint64 (_DURATION (src2), 2000 - 1100);
+
+  current = objects = ges_layer_get_clips (layer);
+  current = objects;
+  assert_equals_int (g_list_length (objects), 4);
   assert_is_type (objects->data, GES_TYPE_TEST_CLIP);
   fail_unless (current->data == src1);
-
-  current = current->next;
-  fail_unless (current->data == src);
-
-  current = current->next;
-  transition = current->data;
-  assert_is_type (transition, GES_TYPE_TRANSITION_CLIP);
-  assert_equals_uint64 (_START (transition), 1000);
-  assert_equals_uint64 (_DURATION (transition), 1100 - 1000);
-
-  current = current->next;
-  transition = current->data;
-  assert_is_type (transition, GES_TYPE_TRANSITION_CLIP);
-  assert_equals_uint64 (_START (transition), 1000);
-  assert_equals_uint64 (_DURATION (transition), 1100 - 1000);
-
-  current = current->next;
-  transition = current->data;
-  assert_is_type (transition, GES_TYPE_TRANSITION_CLIP);
-  assert_equals_uint64 (_START (transition), 1000);
-  assert_equals_uint64 (_DURATION (transition), 1250 - 1000);
-
-  current = current->next;
-  transition = current->data;
-  assert_is_type (transition, GES_TYPE_TRANSITION_CLIP);
-  assert_equals_uint64 (_START (transition), 1000);
-  assert_equals_uint64 (_DURATION (transition), 1250 - 1000);
-
-  current = current->next;
-  fail_unless (current->data == src2);
   g_list_free_full (objects, gst_object_unref);
 
   gst_object_unref (timeline);
