@@ -33,20 +33,6 @@ project_loaded_cb (GESProject * project, GESTimeline * timeline,
   g_main_loop_quit (mainloop);
 }
 
-static gchar *
-get_tmp_uri (const gchar * filename)
-{
-  gchar *location, *uri;
-
-  location = g_build_filename (g_get_tmp_dir (),
-      "test-keyframes-save.xges", NULL);
-
-  uri = g_strconcat ("file://", location, NULL);
-  g_free (location);
-
-  return uri;
-}
-
 GST_START_TEST (test_project_simple)
 {
   gchar *id;
@@ -263,15 +249,15 @@ _test_project (GESProject * project, GESTimeline * timeline)
           if (GES_IS_BASE_EFFECT (trackelement)) {
             guint nb_scratch_lines;
 
-            ges_track_element_get_child_properties (trackelement,
+            ges_timeline_element_get_child_properties (tmptrackelement->data,
                 "scratch-lines", &nb_scratch_lines, NULL);
             assert_equals_int (nb_scratch_lines, 12);
 
-            gnl_object_check (ges_track_element_get_gnlobject (trackelement),
-                0, 1000000000, 0, 1000000000, MIN_GNL_PRIO, TRUE);
+            nle_object_check (ges_track_element_get_nleobject (trackelement),
+                0, 1000000000, 0, 1000000000, MIN_NLE_PRIO, TRUE);
           } else {
-            gnl_object_check (ges_track_element_get_gnlobject (trackelement),
-                0, 1000000000, 0, 1000000000, MIN_GNL_PRIO + 1, TRUE);
+            nle_object_check (ges_track_element_get_nleobject (trackelement),
+                0, 1000000000, 0, 1000000000, MIN_NLE_PRIO + 1, TRUE);
           }
         }
         break;
@@ -297,7 +283,7 @@ _test_project (GESProject * project, GESTimeline * timeline)
 }
 
 static void
-_add_keyframes (GESTimeline * timeline)
+_add_properties (GESTimeline * timeline)
 {
   GList *tracks;
   GList *tmp;
@@ -316,6 +302,7 @@ _add_keyframes (GESTimeline * timeline)
         for (tmp_tck = track_elements; tmp_tck; tmp_tck = tmp_tck->next) {
           GESTrackElement *element = GES_TRACK_ELEMENT (tmp_tck->data);
 
+          /* Adding keyframes */
           if (GES_IS_EFFECT (element)) {
             GstControlSource *source;
             GstControlBinding *tmp_binding, *binding;
@@ -349,6 +336,15 @@ _add_keyframes (GESTimeline * timeline)
             gst_timed_value_control_source_set (GST_TIMED_VALUE_CONTROL_SOURCE
                 (source), 10 * GST_SECOND, 1.);
           }
+          /* Adding children properties */
+          else if (GES_IS_VIDEO_SOURCE (element)) {
+            gint64 posx = 42;
+            ges_timeline_element_set_child_properties (GES_TIMELINE_ELEMENT
+                (element), "posx", posx, NULL);
+            ges_timeline_element_get_child_properties (GES_TIMELINE_ELEMENT
+                (element), "posx", &posx, NULL);
+            fail_unless_equals_int64 (posx, 42);
+          }
         }
         break;
       default:
@@ -358,7 +354,7 @@ _add_keyframes (GESTimeline * timeline)
 }
 
 static void
-_check_keyframes (GESTimeline * timeline)
+_check_properties (GESTimeline * timeline)
 {
   GList *tracks;
   GList *tmp;
@@ -376,7 +372,7 @@ _check_keyframes (GESTimeline * timeline)
 
         for (tmp_tck = track_elements; tmp_tck; tmp_tck = tmp_tck->next) {
           GESTrackElement *element = GES_TRACK_ELEMENT (tmp_tck->data);
-
+          /* Checking keyframes */
           if (GES_IS_EFFECT (element)) {
             GstControlBinding *binding;
             GstControlSource *source;
@@ -406,6 +402,14 @@ _check_keyframes (GESTimeline * timeline)
             fail_unless (value->value == 1.);
             fail_unless (value->timestamp == 10 * GST_SECOND);
           }
+          /* Checking children properties */
+          else if (GES_IS_VIDEO_SOURCE (element)) {
+            /* Init 'posx' with a wrong value */
+            gint64 posx = 27;
+            ges_timeline_element_get_child_properties (GES_TIMELINE_ELEMENT
+                (element), "posx", &posx, NULL);
+            fail_unless_equals_int64 (posx, 42);
+          }
         }
         break;
       default:
@@ -414,13 +418,13 @@ _check_keyframes (GESTimeline * timeline)
   }
 }
 
-GST_START_TEST (test_project_add_keyframes)
+GST_START_TEST (test_project_add_properties)
 {
   GESProject *project;
   GESTimeline *timeline;
   GESAsset *formatter_asset;
   gboolean saved;
-  gchar *uri = ges_test_file_uri ("test-keyframes.xges");
+  gchar *uri = ges_test_file_uri ("test-properties.xges");
 
   project = ges_project_new (uri);
   mainloop = g_main_loop_new (NULL, FALSE);
@@ -439,9 +443,9 @@ GST_START_TEST (test_project_add_keyframes)
 
   g_free (uri);
 
-  _add_keyframes (timeline);
+  _add_properties (timeline);
 
-  uri = get_tmp_uri ("test-keyframes-save.xges");
+  uri = ges_test_get_tmp_uri ("test-properties-save.xges");
   formatter_asset = ges_asset_request (GES_TYPE_FORMATTER, "ges", NULL);
   saved =
       ges_project_save (project, timeline, uri, formatter_asset, TRUE, NULL);
@@ -462,7 +466,7 @@ GST_START_TEST (test_project_add_keyframes)
 
   g_main_loop_run (mainloop);
 
-  _check_keyframes (timeline);
+  _check_properties (timeline);
 
   gst_object_unref (timeline);
   gst_object_unref (project);
@@ -480,63 +484,77 @@ GST_END_TEST;
 GST_START_TEST (test_project_load_xges)
 {
   gboolean saved;
-  GESProject *project;
+  GESProject *loaded_project, *saved_project;
   GESTimeline *timeline;
   GESAsset *formatter_asset;
   gchar *uri = ges_test_file_uri ("test-project.xges");
 
-  project = ges_project_new (uri);
+  loaded_project = ges_project_new (uri);
   mainloop = g_main_loop_new (NULL, FALSE);
-  fail_unless (GES_IS_PROJECT (project));
+  fail_unless (GES_IS_PROJECT (loaded_project));
 
   /* Connect the signals */
-  g_signal_connect (project, "asset-added", (GCallback) asset_added_cb, NULL);
-  g_signal_connect (project, "loaded", (GCallback) project_loaded_cb, mainloop);
+  g_signal_connect (loaded_project, "asset-added", (GCallback) asset_added_cb,
+      NULL);
+  g_signal_connect (loaded_project, "loaded", (GCallback) project_loaded_cb,
+      mainloop);
 
   /* Make sure we update the project's dummy URL to some actual URL */
-  g_signal_connect (project, "missing-uri", (GCallback) _set_new_uri, NULL);
+  g_signal_connect (loaded_project, "missing-uri", (GCallback) _set_new_uri,
+      NULL);
 
   /* Now extract a timeline from it */
   GST_LOG ("Loading project");
-  timeline = GES_TIMELINE (ges_asset_extract (GES_ASSET (project), NULL));
+  timeline =
+      GES_TIMELINE (ges_asset_extract (GES_ASSET (loaded_project), NULL));
   fail_unless (GES_IS_TIMELINE (timeline));
-  assert_equals_int (g_list_length (ges_project_get_loading_assets (project)),
-      1);
+  assert_equals_int (g_list_length (ges_project_get_loading_assets
+          (loaded_project)), 1);
 
   g_main_loop_run (mainloop);
   GST_LOG ("Test first loading");
-  _test_project (project, timeline);
+  _test_project (loaded_project, timeline);
   g_free (uri);
 
-  uri = get_tmp_uri ("test-project_TMP.xges");
+  uri = ges_test_get_tmp_uri ("test-project_TMP.xges");
   formatter_asset = ges_asset_request (GES_TYPE_FORMATTER, "ges", NULL);
   saved =
-      ges_project_save (project, timeline, uri, formatter_asset, TRUE, NULL);
+      ges_project_save (loaded_project, timeline, uri, formatter_asset, TRUE,
+      NULL);
   fail_unless (saved);
   gst_object_unref (timeline);
-  gst_object_unref (project);
 
-  project = ges_project_new (uri);
-  ASSERT_OBJECT_REFCOUNT (project, "Our + cache", 2);
-  g_signal_connect (project, "asset-added", (GCallback) asset_added_cb, NULL);
-  g_signal_connect (project, "loaded", (GCallback) project_loaded_cb, mainloop);
+  saved_project = ges_project_new (uri);
+  ASSERT_OBJECT_REFCOUNT (saved_project, "Our + cache", 2);
+  g_signal_connect (saved_project, "asset-added", (GCallback) asset_added_cb,
+      NULL);
+  g_signal_connect (saved_project, "loaded", (GCallback) project_loaded_cb,
+      mainloop);
 
   GST_LOG ("Loading saved project");
-  timeline = GES_TIMELINE (ges_asset_extract (GES_ASSET (project), NULL));
+  timeline = GES_TIMELINE (ges_asset_extract (GES_ASSET (saved_project), NULL));
   fail_unless (GES_IS_TIMELINE (timeline));
   g_main_loop_run (mainloop);
-  _test_project (project, timeline);
+  _test_project (saved_project, timeline);
+
+  fail_unless (ges_meta_container_get_string (GES_META_CONTAINER
+          (loaded_project), GES_META_FORMAT_VERSION));
+  fail_unless_equals_string (ges_meta_container_get_string (GES_META_CONTAINER
+          (loaded_project), GES_META_FORMAT_VERSION),
+      ges_meta_container_get_string (GES_META_CONTAINER (loaded_project),
+          GES_META_FORMAT_VERSION));
   gst_object_unref (timeline);
-  gst_object_unref (project);
+  gst_object_unref (saved_project);
+  gst_object_unref (loaded_project);
   g_free (uri);
 
-  ASSERT_OBJECT_REFCOUNT (project, "Still 1 ref for asset cache", 1);
+  ASSERT_OBJECT_REFCOUNT (saved_project, "Still 1 ref for asset cache", 1);
 
   g_main_loop_unref (mainloop);
-  g_signal_handlers_disconnect_by_func (project, (GCallback) project_loaded_cb,
-      mainloop);
-  g_signal_handlers_disconnect_by_func (project, (GCallback) asset_added_cb,
-      NULL);
+  g_signal_handlers_disconnect_by_func (saved_project,
+      (GCallback) project_loaded_cb, mainloop);
+  g_signal_handlers_disconnect_by_func (saved_project,
+      (GCallback) asset_added_cb, NULL);
 }
 
 GST_END_TEST;
@@ -579,7 +597,7 @@ GST_START_TEST (test_project_auto_transition)
   /* Set timeline and layers auto-transition to TRUE */
   ges_timeline_set_auto_transition (timeline, TRUE);
 
-  tmpuri = get_tmp_uri ("test-auto-transition-save.xges");
+  tmpuri = ges_test_get_tmp_uri ("test-auto-transition-save.xges");
   formatter_asset = ges_asset_request (GES_TYPE_FORMATTER, "ges", NULL);
   saved =
       ges_project_save (project, timeline, tmpuri, formatter_asset, TRUE, NULL);
@@ -720,7 +738,7 @@ ges_suite (void)
   tcase_add_test (tc_chain, test_project_simple);
   tcase_add_test (tc_chain, test_project_add_assets);
   tcase_add_test (tc_chain, test_project_load_xges);
-  tcase_add_test (tc_chain, test_project_add_keyframes);
+  tcase_add_test (tc_chain, test_project_add_properties);
   tcase_add_test (tc_chain, test_project_auto_transition);
   /*tcase_add_test (tc_chain, test_load_xges_and_play); */
   tcase_add_test (tc_chain, test_project_unexistant_effect);
