@@ -47,8 +47,6 @@ GST_START_TEST (test_basic_timeline_edition)
   GESTrackElement *trackelement, *trackelement1, *trackelement2;
   GESContainer *clip, *clip1, *clip2;
 
-  ges_init ();
-
   track = GES_TRACK (ges_audio_track_new ());
   fail_unless (track != NULL);
 
@@ -218,21 +216,17 @@ GST_START_TEST (test_basic_timeline_edition)
    *          |  clip1 ||   clip  ||  clip2     |
    * time    20------ 25 ------ 62 ---------122
    */
-  fail_unless (ges_container_edit (clip, NULL, -1, GES_EDIT_MODE_TRIM,
-          GES_EDGE_START, 40) == TRUE);
-  fail_unless (ges_container_edit (clip, NULL, -1, GES_EDIT_MODE_ROLL,
-          GES_EDGE_START, 25) == TRUE);
-  CHECK_OBJECT_PROPS (trackelement, 25, 0, 37);
-  CHECK_OBJECT_PROPS (trackelement1, 20, 0, 5);
+  fail_if (ges_container_edit (clip, NULL, -1, GES_EDIT_MODE_ROLL,
+          GES_EDGE_START, 25));
+  CHECK_OBJECT_PROPS (trackelement, 40, 3, 22);
+  CHECK_OBJECT_PROPS (trackelement1, 20, 0, 20);
   CHECK_OBJECT_PROPS (trackelement2, 62, 0, 60);
 
   /* Make sure that not doing anything when not able to roll */
-  fail_unless (ges_container_edit (clip, NULL, -1, GES_EDIT_MODE_ROLL,
-          GES_EDGE_START, 65) == TRUE);
-  fail_unless (ges_container_edit (clip1, NULL, -1, GES_EDIT_MODE_ROLL,
+  fail_if (ges_container_edit (clip1, NULL, -1, GES_EDIT_MODE_ROLL,
           GES_EDGE_END, 65) == TRUE, 0);
-  CHECK_OBJECT_PROPS (trackelement, 25, 0, 37);
-  CHECK_OBJECT_PROPS (trackelement1, 20, 0, 5);
+  CHECK_OBJECT_PROPS (trackelement, 40, 3, 22);
+  CHECK_OBJECT_PROPS (trackelement1, 20, 0, 20);
   CHECK_OBJECT_PROPS (trackelement2, 62, 0, 60);
 
   gst_object_unref (timeline);
@@ -249,8 +243,6 @@ GST_START_TEST (test_snapping)
   GESLayer *layer;
   GList *trackelements;
 
-  ges_init ();
-
   track = GES_TRACK (ges_video_track_new ());
   fail_unless (track != NULL);
 
@@ -324,8 +316,8 @@ GST_START_TEST (test_snapping)
   CHECK_OBJECT_PROPS (trackelement2, 62, 0, 60);
 
   /* Snaping to edge, so no move */
-  fail_unless (ges_container_edit (clip1, NULL, -1, GES_EDIT_MODE_TRIM,
-          GES_EDGE_END, 27) == TRUE);
+  fail_if (ges_container_edit (clip1, NULL, -1, GES_EDIT_MODE_TRIM,
+          GES_EDGE_END, 27));
   CHECK_OBJECT_PROPS (trackelement, 25, 0, 37);
   CHECK_OBJECT_PROPS (trackelement1, 20, 0, 5);
   CHECK_OBJECT_PROPS (trackelement2, 62, 0, 60);
@@ -493,8 +485,6 @@ GST_START_TEST (test_simple_triming)
 
   gchar *uri = ges_test_file_uri ("audio_video.ogg");
 
-  ges_init ();
-
   project = ges_project_new (NULL);
 
   mainloop = g_main_loop_new (NULL, FALSE);
@@ -535,7 +525,6 @@ GST_END_TEST;
 
 GST_START_TEST (test_timeline_edition_mode)
 {
-  guint i;
   GESTrack *track;
   GESTimeline *timeline;
   GESTrackElement *trackelement, *trackelement1, *trackelement2;
@@ -543,8 +532,6 @@ GST_START_TEST (test_timeline_edition_mode)
   GESLayer *layer, *layer1, *layer2;
   GList *trackelements, *layers, *tmp;
 
-  ges_init ();
-
   track = GES_TRACK (ges_video_track_new ());
   fail_unless (track != NULL);
 
@@ -743,18 +730,6 @@ GST_START_TEST (test_timeline_edition_mode)
   assert_equals_int (ges_layer_get_priority (layer), 2);
   gst_object_unref (layer);
 
-  /* Some more intensive roll testing */
-  for (i = 0; i < 20; i++) {
-    gint32 random = g_random_int_range (35, 94);
-    guint64 tck3_inpoint = random - 35;
-
-    fail_unless (ges_container_edit (clip, NULL, -1, GES_EDIT_MODE_ROLL,
-            GES_EDGE_END, random) == TRUE);
-    CHECK_OBJECT_PROPS (trackelement, 32, 5, random - 32);
-    CHECK_OBJECT_PROPS (trackelement1, 20, 0, 10);
-    CHECK_OBJECT_PROPS (trackelement2, random, tck3_inpoint, 95 - random);
-  }
-
   /* Roll end clip back to 35
    * New timeline:
    * ------------
@@ -882,6 +857,7 @@ GST_START_TEST (test_timeline_edition_mode)
    *                     25------62
    *
    */
+  ges_timeline_element_set_inpoint (GES_TIMELINE_ELEMENT (clip), 15);
   fail_unless (ges_container_edit (clip1, NULL, -1, GES_EDIT_MODE_ROLL,
           GES_EDGE_END, 25) == TRUE);
   CHECK_OBJECT_PROPS (trackelement, 25, 0, 37);
@@ -889,25 +865,25 @@ GST_START_TEST (test_timeline_edition_mode)
   CHECK_OBJECT_PROPS (trackelement2, 62, 0, 60);
 
   /* Make sure that not doing anything when not able to roll */
-  fail_unless (ges_container_edit (clip, NULL, -1, GES_EDIT_MODE_ROLL,
-          GES_EDGE_START, 65) == TRUE);
-  fail_unless (ges_container_edit (clip1, NULL, -1, GES_EDIT_MODE_ROLL,
-          GES_EDGE_END, 65) == TRUE, 0);
+  fail_if (ges_container_edit (clip, NULL, -1, GES_EDIT_MODE_ROLL,
+          GES_EDGE_START, 65));
+  fail_if (ges_container_edit (clip1, NULL, -1, GES_EDIT_MODE_ROLL,
+          GES_EDGE_END, 65));
   CHECK_OBJECT_PROPS (trackelement, 25, 0, 37);
   CHECK_OBJECT_PROPS (trackelement1, 20, 0, 5);
   CHECK_OBJECT_PROPS (trackelement2, 62, 0, 60);
 
   /* Snaping to edge, so no move */
   g_object_set (timeline, "snapping-distance", (guint64) 3, NULL);
-  fail_unless (ges_container_edit (clip1, NULL, -1, GES_EDIT_MODE_TRIM,
-          GES_EDGE_END, 27) == TRUE);
+  fail_if (ges_container_edit (clip1, NULL, -1, GES_EDIT_MODE_TRIM,
+          GES_EDGE_END, 27));
   CHECK_OBJECT_PROPS (trackelement, 25, 0, 37);
   CHECK_OBJECT_PROPS (trackelement1, 20, 0, 5);
   CHECK_OBJECT_PROPS (trackelement2, 62, 0, 60);
 
   /* Snaping to edge, so no move */
-  fail_unless (ges_container_edit (clip1, NULL, -1, GES_EDIT_MODE_TRIM,
-          GES_EDGE_END, 27) == TRUE);
+  fail_if (ges_container_edit (clip1, NULL, -1, GES_EDIT_MODE_TRIM,
+          GES_EDGE_END, 27));
 
   CHECK_OBJECT_PROPS (trackelement, 25, 0, 37);
   CHECK_OBJECT_PROPS (trackelement1, 20, 0, 5);
@@ -991,8 +967,6 @@ GST_START_TEST (test_groups)
 
   GList *clips = NULL;
 
-  ges_init ();
-
   timeline = ges_timeline_new_audio_video ();
 
   /* Our timeline
@@ -1177,8 +1151,6 @@ GST_START_TEST (test_snapping_groups)
 
   GList *clips = NULL;
 
-  ges_init ();
-
   timeline = ges_timeline_new_audio_video ();
   g_object_set (timeline, "snapping-distance", (guint64) 3, NULL);
 
@@ -1277,9 +1249,11 @@ _set_track_element_width_height (GESTrackElement * trksrc, gint wvalue,
   g_value_set_int (&width, wvalue);
   g_value_set_int (&height, hvalue);
   if (wvalue >= 0)
-    ges_track_element_set_child_property (trksrc, "width", &width);
+    ges_timeline_element_set_child_property (GES_TIMELINE_ELEMENT (trksrc),
+        "width", &width);
   if (hvalue >= 0)
-    ges_track_element_set_child_property (trksrc, "height", &height);
+    ges_timeline_element_set_child_property (GES_TIMELINE_ELEMENT (trksrc),
+        "height", &height);
 }
 
 static gboolean
@@ -1297,12 +1271,17 @@ check_frame_positionner_size (GESClip * clip, gint width, gint height)
   g_value_init (&val_width, G_TYPE_INT);
   g_value_init (&val_height, G_TYPE_INT);
 
-  ges_track_element_get_child_property (trksrc, "width", &val_width);
-  ges_track_element_get_child_property (trksrc, "height", &val_height);
+  ges_timeline_element_get_child_property (GES_TIMELINE_ELEMENT (trksrc),
+      "width", &val_width);
+  ges_timeline_element_get_child_property (GES_TIMELINE_ELEMENT (trksrc),
+      "height", &val_height);
 
   real_width = g_value_get_int (&val_width);
   real_height = g_value_get_int (&val_height);
 
+  assert_equals_int (real_width, width);
+  assert_equals_int (real_height, height);
+
   return (width == real_width && height == real_height);
 }
 
@@ -1317,7 +1296,6 @@ GST_START_TEST (test_scaling)
       gst_caps_new_simple ("video/x-raw", "width", G_TYPE_INT, 1200, "height",
       G_TYPE_INT, 1000, NULL);
 
-  ges_init ();
   timeline = ges_timeline_new ();
   ges_timeline_add_track (timeline, trackv);
   layer = ges_layer_new ();
@@ -1471,6 +1449,33 @@ GST_START_TEST (test_scaling)
   /* Clip width was set to 0 so it has to use natural clip width */
   /* Clip height was set to 0 so it has to use natural clip height */
   fail_unless (check_frame_positionner_size (clip, 0, 0));
+
+
+  /**
+   * Our timeline : 320 * 240
+   *
+   * 0--------------0
+   * | width : 320  |
+   * | height: 240  |
+   * 0--------------2
+   */
+
+  /* We set the restriction caps video size to the same as the video source
+   * size. */
+  caps = gst_caps_from_string ("video/x-raw,height=240,width=320");
+  ges_track_set_restriction_caps (trackv, caps);
+  gst_caps_unref (caps);
+  _set_track_element_width_height (GES_CONTAINER_CHILDREN (clip)->data, 320,
+      240);
+
+  /* As the video source as the same size as the track restriction caps, changing
+   * the track size through restriction caps should also change the video source
+   * size */
+  caps = gst_caps_from_string ("video/x-raw,height=1080,width=1920");
+  ges_track_set_restriction_caps (trackv, caps);
+  fail_unless (check_frame_positionner_size (clip, 1920, 1080));
+
+  gst_object_unref (timeline);
 }
 
 GST_END_TEST;
@@ -1481,6 +1486,8 @@ ges_suite (void)
   Suite *s = suite_create ("ges-timeline-edition");
   TCase *tc_chain = tcase_create ("timeline-edition");
 
+  ges_init ();
+
   suite_add_tcase (s, tc_chain);
 
   tcase_add_test (tc_chain, test_basic_timeline_edition);
