@@ -47,7 +47,7 @@ asset_created_cb (GObject * source, GAsyncResult * res, gpointer udata)
 
   asset = ges_asset_request_finish (res, &error);
   ASSERT_OBJECT_REFCOUNT (asset, "1 for us + for the cache + 1 taken "
-      "by g_simple_async_result_complete_in_idle", 3);
+      "by g_task", 3);
   fail_unless (error == NULL);
   fail_if (asset == NULL);
   fail_if (g_strcmp0 (ges_asset_get_id (asset), av_uri));
@@ -167,8 +167,8 @@ GST_START_TEST (test_filesource_properties)
   assert_equals_uint64 (_INPOINT (trackelement), 12);
 
   /* And let's also check that it propagated correctly to GNonLin */
-  gnl_object_check (ges_track_element_get_gnlobject (trackelement), 42, 51, 12,
-      51, MIN_GNL_PRIO, TRUE);
+  nle_object_check (ges_track_element_get_nleobject (trackelement), 42, 51, 12,
+      51, MIN_NLE_PRIO, TRUE);
 
   /* Change more properties, see if they propagate */
   g_object_set (clip, "start", (guint64) 420, "duration", (guint64) 510,
@@ -182,18 +182,18 @@ GST_START_TEST (test_filesource_properties)
   assert_equals_uint64 (_INPOINT (trackelement), 120);
 
   /* And let's also check that it propagated correctly to GNonLin */
-  gnl_object_check (ges_track_element_get_gnlobject (trackelement), 420, 510,
-      120, 510, MIN_GNL_PRIO + 0, TRUE);
+  nle_object_check (ges_track_element_get_nleobject (trackelement), 420, 510,
+      120, 510, MIN_NLE_PRIO + 0, TRUE);
 
   /* Test mute support */
   g_object_set (clip, "mute", TRUE, NULL);
   ges_timeline_commit (timeline);
-  gnl_object_check (ges_track_element_get_gnlobject (trackelement), 420, 510,
-      120, 510, MIN_GNL_PRIO + 0, FALSE);
+  nle_object_check (ges_track_element_get_nleobject (trackelement), 420, 510,
+      120, 510, MIN_NLE_PRIO + 0, FALSE);
   g_object_set (clip, "mute", FALSE, NULL);
   ges_timeline_commit (timeline);
-  gnl_object_check (ges_track_element_get_gnlobject (trackelement), 420, 510,
-      120, 510, MIN_GNL_PRIO + 0, TRUE);
+  nle_object_check (ges_track_element_get_nleobject (trackelement), 420, 510,
+      120, 510, MIN_NLE_PRIO + 0, TRUE);
 
   ges_container_remove (GES_CONTAINER (clip),
       GES_TIMELINE_ELEMENT (trackelement));
